--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "geodetic_datum" VALUES('EPSG','1024','Hungarian Datum 1909',NULL,'EPSG','7004','EPSG','8901','1909-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13076','geodetic_datum','EPSG','1024','EPSG','1119','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','1025','Taiwan Datum 1967',NULL,'EPSG','7050','EPSG','8901','1967-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13077','geodetic_datum','EPSG','1025','EPSG','3315','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1026','Taiwan Datum 1997',NULL,'EPSG','7019','EPSG','8901','1997-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13078','geodetic_datum','EPSG','1026','EPSG','1228','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1029','Iraqi Geospatial Reference System',NULL,'EPSG','7019','EPSG','8901','1997-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13081','geodetic_datum','EPSG','1029','EPSG','1124','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1031','MGI 1901',NULL,'EPSG','7004','EPSG','8901','1901-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13083','geodetic_datum','EPSG','1031','EPSG','2370','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1032','MOLDREF99',NULL,'EPSG','7019','EPSG','8901','1999-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13084','geodetic_datum','EPSG','1032','EPSG','1162','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1033','Reseau Geodesique de la RDC 2005',NULL,'EPSG','7019','EPSG','8901','2005-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13085','geodetic_datum','EPSG','1033','EPSG','3613','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1034','Serbian Reference Network 1998',NULL,'EPSG','7019','EPSG','8901','1998-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13086','geodetic_datum','EPSG','1034','EPSG','4543','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1035','Red Geodesica de Canarias 1995',NULL,'EPSG','7019','EPSG','8901','2007-08-29',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13087','geodetic_datum','EPSG','1035','EPSG','3199','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1036','Reseau Geodesique de Mayotte 2004',NULL,'EPSG','7019','EPSG','8901','2004-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13088','geodetic_datum','EPSG','1036','EPSG','1159','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1037','Cadastre 1997',NULL,'EPSG','7022','EPSG','8901','1997-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13089','geodetic_datum','EPSG','1037','EPSG','3340','EPSG','1028');
INSERT INTO "geodetic_datum" VALUES('EPSG','1038','Reseau Geodesique de Saint Pierre et Miquelon 2006',NULL,'EPSG','7019','EPSG','8901','2006-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13090','geodetic_datum','EPSG','1038','EPSG','1220','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1041','Autonomous Regions of Portugal 2008',NULL,'EPSG','7019','EPSG','8901','2008-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13093','geodetic_datum','EPSG','1041','EPSG','3670','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1042','Mexico ITRF92',NULL,'EPSG','7019','EPSG','8901','1992-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13094','geodetic_datum','EPSG','1042','EPSG','1160','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1043','China 2000',NULL,'EPSG','1024','EPSG','8901','2000-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13095','geodetic_datum','EPSG','1043','EPSG','1067','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1044','Sao Tome',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13096','geodetic_datum','EPSG','1044','EPSG','3645','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','1045','New Beijing',NULL,'EPSG','7024','EPSG','8901','1982-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13097','geodetic_datum','EPSG','1045','EPSG','3228','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','1046','Principe',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13098','geodetic_datum','EPSG','1046','EPSG','3646','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','1047','Reseau de Reference des Antilles Francaises 1991',NULL,'EPSG','7019','EPSG','8901','1991-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13099','geodetic_datum','EPSG','1047','EPSG','2824','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1048','Tokyo 1892',NULL,'EPSG','7004','EPSG','8901','1892-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13100','geodetic_datum','EPSG','1048','EPSG','1364','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','1052','System of the Unified Trigonometrical Cadastral Network/05',NULL,'EPSG','7004','EPSG','8901','2009-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13104','geodetic_datum','EPSG','1052','EPSG','1079','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1053','Sri Lanka Datum 1999',NULL,'EPSG','7015','EPSG','8901','1999-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13105','geodetic_datum','EPSG','1053','EPSG','3310','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','1055','System of the Unified Trigonometrical Cadastral Network/05 (Ferro)',NULL,'EPSG','7004','EPSG','8909','2009-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13107','geodetic_datum','EPSG','1055','EPSG','1079','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1056','Geocentric Datum Brunei Darussalam 2009',NULL,'EPSG','7019','EPSG','8901','2009-07-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13108','geodetic_datum','EPSG','1056','EPSG','1055','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1057','Turkish National Reference Frame',NULL,'EPSG','7019','EPSG','8901','2005-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13109','geodetic_datum','EPSG','1057','EPSG','1237','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1058','Bhutan National Geodetic Datum',NULL,'EPSG','7019','EPSG','8901','2003-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13110','geodetic_datum','EPSG','1058','EPSG','1048','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1060','Islands Net 2004',NULL,'EPSG','7019','EPSG','8901','2004-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13112','geodetic_datum','EPSG','1060','EPSG','1120','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1061','International Terrestrial Reference Frame 2008',NULL,'EPSG','7019','EPSG','8901','2005-01-01',2005.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13113','geodetic_datum','EPSG','1061','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1062','Posiciones Geodesicas Argentinas 2007',NULL,'EPSG','7030','EPSG','8901','2006-08-19',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13114','geodetic_datum','EPSG','1062','EPSG','1033','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','1063','Marco Geodesico Nacional de Bolivia',NULL,'EPSG','7019','EPSG','8901','2010-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13115','geodetic_datum','EPSG','1063','EPSG','1049','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1064','SIRGAS-Chile realization 1 epoch 2002',NULL,'EPSG','7019','EPSG','8901','2002-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13116','geodetic_datum','EPSG','1064','EPSG','1066','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1065','Costa Rica 2005',NULL,'EPSG','7030','EPSG','8901','2007-07-30',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13117','geodetic_datum','EPSG','1065','EPSG','1074','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1066','Sistema Geodesico Nacional de Panama MACARIO SOLIS',NULL,'EPSG','7019','EPSG','8901','2000-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13118','geodetic_datum','EPSG','1066','EPSG','1186','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1067','Peru96',NULL,'EPSG','7019','EPSG','8901','1996-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13119','geodetic_datum','EPSG','1067','EPSG','1189','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1068','SIRGAS-ROU98',NULL,'EPSG','7030','EPSG','8901','1998-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13120','geodetic_datum','EPSG','1068','EPSG','1247','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1069','SIRGAS_ES2007.8',NULL,'EPSG','7019','EPSG','8901','2007-11-07',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13121','geodetic_datum','EPSG','1069','EPSG','1087','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1070','Ocotepeque 1935',NULL,'EPSG','7008','EPSG','8901','1935-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13122','geodetic_datum','EPSG','1070','EPSG','3876','EPSG','1142');
INSERT INTO "geodetic_datum" VALUES('EPSG','1071','Sibun Gorge 1922',NULL,'EPSG','7007','EPSG','8901','1922-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13123','geodetic_datum','EPSG','1071','EPSG','3219','EPSG','1142');
INSERT INTO "geodetic_datum" VALUES('EPSG','1072','Panama-Colon 1911',NULL,'EPSG','7008','EPSG','8901','1911-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13124','geodetic_datum','EPSG','1072','EPSG','3290','EPSG','1142');
INSERT INTO "geodetic_datum" VALUES('EPSG','1073','Reseau Geodesique des Antilles Francaises 2009',NULL,'EPSG','7019','EPSG','8901','2009-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13125','geodetic_datum','EPSG','1073','EPSG','2824','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1074','Corrego Alegre 1961',NULL,'EPSG','7022','EPSG','8901','1961-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13126','geodetic_datum','EPSG','1074','EPSG','3874','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','1075','South American Datum 1969(96)',NULL,'EPSG','7050','EPSG','8901','1996-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13127','geodetic_datum','EPSG','1075','EPSG','1053','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','1076','Papua New Guinea Geodetic Datum 1994',NULL,'EPSG','7019','EPSG','8901','1994-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13128','geodetic_datum','EPSG','1076','EPSG','1187','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1077','Ukraine 2000',NULL,'EPSG','7024','EPSG','8901','2003-09-17',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13129','geodetic_datum','EPSG','1077','EPSG','1242','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1078','Fehmarnbelt Datum 2010',NULL,'EPSG','7019','EPSG','8901','2010-02-21',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13130','geodetic_datum','EPSG','1078','EPSG','3889','EPSG','1139');
INSERT INTO "geodetic_datum" VALUES('EPSG','1081','Deutsche Bahn Reference System',NULL,'EPSG','7004','EPSG','8901','2001-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13133','geodetic_datum','EPSG','1081','EPSG','3339','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1095','Tonga Geodetic Datum 2005',NULL,'EPSG','7019','EPSG','8901','2005-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13147','geodetic_datum','EPSG','1095','EPSG','1234','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1100','Cayman Islands Geodetic Datum 2011',NULL,'EPSG','7019','EPSG','8901','2011-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13152','geodetic_datum','EPSG','1100','EPSG','1063','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1111','Nepal 1981',NULL,'EPSG','7015','EPSG','8901','1981-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13163','geodetic_datum','EPSG','1111','EPSG','1171','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','1112','Cyprus Geodetic Reference System 1993',NULL,'EPSG','7030','EPSG','8901','1993-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13164','geodetic_datum','EPSG','1112','EPSG','3236','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','1113','Reseau Geodesique des Terres Australes et Antarctiques Francaises 2007',NULL,'EPSG','7019','EPSG','8901','2007-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13165','geodetic_datum','EPSG','1113','EPSG','4246','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1114','Israeli Geodetic Datum 2005',NULL,'EPSG','7030','EPSG','8901','2004-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13166','geodetic_datum','EPSG','1114','EPSG','1126','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1115','Israeli Geodetic Datum 2005(2012)',NULL,'EPSG','7030','EPSG','8901','2012-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13167','geodetic_datum','EPSG','1115','EPSG','1126','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1116','NAD83 (National Spatial Reference System 2011)',NULL,'EPSG','7019','EPSG','8901','2012-06-12',NULL,NULL,NULL,2010.0,0);
INSERT INTO "usage" VALUES('EPSG','13168','geodetic_datum','EPSG','1116','EPSG','1511','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1117','NAD83 (National Spatial Reference System PA11)',NULL,'EPSG','7019','EPSG','8901','2012-06-12',NULL,NULL,NULL,2010.0,0);
INSERT INTO "usage" VALUES('EPSG','13169','geodetic_datum','EPSG','1117','EPSG','4162','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1118','NAD83 (National Spatial Reference System MA11)',NULL,'EPSG','7019','EPSG','8901','2012-06-12',NULL,NULL,NULL,2010.0,0);
INSERT INTO "usage" VALUES('EPSG','13170','geodetic_datum','EPSG','1118','EPSG','4167','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1120','Mexico ITRF2008',NULL,'EPSG','7019','EPSG','8901','2010-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13172','geodetic_datum','EPSG','1120','EPSG','1160','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1128','Japanese Geodetic Datum 2011',NULL,'EPSG','7019','EPSG','8901','2011-10-21',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13180','geodetic_datum','EPSG','1128','EPSG','1129','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1132','Rete Dinamica Nazionale 2008',NULL,'EPSG','7019','EPSG','8901','2008-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13184','geodetic_datum','EPSG','1132','EPSG','3343','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','1133','NAD83 (Continuously Operating Reference Station 1996)',NULL,'EPSG','7019','EPSG','8901','1998-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13185','geodetic_datum','EPSG','1133','EPSG','1511','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1135','Aden 1925',NULL,'EPSG','7012','EPSG','8901','1925-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13187','geodetic_datum','EPSG','1135','EPSG','1340','EPSG','1138');
INSERT INTO "geodetic_datum" VALUES('EPSG','1136','Bioko',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13188','geodetic_datum','EPSG','1136','EPSG','4220','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','1137','Bekaa Valley 1920',NULL,'EPSG','7012','EPSG','8901','1920-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13189','geodetic_datum','EPSG','1137','EPSG','3269','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','1138','South East Island 1943',NULL,'EPSG','7012','EPSG','8901','1975-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13190','geodetic_datum','EPSG','1138','EPSG','4183','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','1139','Gambia',NULL,'EPSG','7012','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13191','geodetic_datum','EPSG','1139','EPSG','3250','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','1141','IGS08',NULL,'EPSG','7019','EPSG','8901','2005-01-01',2005.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13193','geodetic_datum','EPSG','1141','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1142','IG05 Intermediate Datum',NULL,'EPSG','7019','EPSG','8901','2004-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13194','geodetic_datum','EPSG','1142','EPSG','2603','EPSG','1203');
INSERT INTO "geodetic_datum" VALUES('EPSG','1143','Israeli Geodetic Datum 2005',NULL,'EPSG','7019','EPSG','8901','2004-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13195','geodetic_datum','EPSG','1143','EPSG','1126','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1144','IG05/12 Intermediate Datum',NULL,'EPSG','7019','EPSG','8901','2012-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13196','geodetic_datum','EPSG','1144','EPSG','2603','EPSG','1203');
INSERT INTO "geodetic_datum" VALUES('EPSG','1145','Israeli Geodetic Datum 2005(2012)',NULL,'EPSG','7019','EPSG','8901','2012-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13197','geodetic_datum','EPSG','1145','EPSG','1126','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1147','Oman National Geodetic Datum 2014',NULL,'EPSG','7019','EPSG','8901','2013-12-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13199','geodetic_datum','EPSG','1147','EPSG','1183','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1152','World Geodetic System 1984 (G730)',NULL,'EPSG','7030','EPSG','8901','1994-01-01',1994.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13204','geodetic_datum','EPSG','1152','EPSG','1262','EPSG','1176');
INSERT INTO "geodetic_datum" VALUES('EPSG','1153','World Geodetic System 1984 (G873)',NULL,'EPSG','7030','EPSG','8901','1997-01-01',1997.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13205','geodetic_datum','EPSG','1153','EPSG','1262','EPSG','1176');
INSERT INTO "geodetic_datum" VALUES('EPSG','1154','World Geodetic System 1984 (G1150)',NULL,'EPSG','7030','EPSG','8901','2001-01-01',2001.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13206','geodetic_datum','EPSG','1154','EPSG','1262','EPSG','1176');
INSERT INTO "geodetic_datum" VALUES('EPSG','1155','World Geodetic System 1984 (G1674)',NULL,'EPSG','7030','EPSG','8901','2005-01-01',2005.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13207','geodetic_datum','EPSG','1155','EPSG','1262','EPSG','1176');
INSERT INTO "geodetic_datum" VALUES('EPSG','1156','World Geodetic System 1984 (G1762)',NULL,'EPSG','7030','EPSG','8901','2005-01-01',2005.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13208','geodetic_datum','EPSG','1156','EPSG','1262','EPSG','1176');
INSERT INTO "geodetic_datum" VALUES('EPSG','1157','Parametry Zemli 1990.02',NULL,'EPSG','7054','EPSG','8901','2002-01-01',2002.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13209','geodetic_datum','EPSG','1157','EPSG','1262','EPSG','1177');
INSERT INTO "geodetic_datum" VALUES('EPSG','1158','Parametry Zemli 1990.11',NULL,'EPSG','7054','EPSG','8901','2010-01-01',2010.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13210','geodetic_datum','EPSG','1158','EPSG','1262','EPSG','1177');
INSERT INTO "geodetic_datum" VALUES('EPSG','1159','Geodezicheskaya Sistema Koordinat 2011',NULL,'EPSG','1025','EPSG','8901','2012-12-28',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13211','geodetic_datum','EPSG','1159','EPSG','1198','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1160','Kyrgyzstan Geodetic Datum 2006',NULL,'EPSG','7019','EPSG','8901','2006-09-13',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13212','geodetic_datum','EPSG','1160','EPSG','1137','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1165','International Terrestrial Reference Frame 2014',NULL,'EPSG','7019','EPSG','8901','2010-01-01',2010.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13217','geodetic_datum','EPSG','1165','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1166','World Geodetic System 1984 (Transit)',NULL,'EPSG','7030','EPSG','8901','1984-01-01',1984.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13218','geodetic_datum','EPSG','1166','EPSG','1262','EPSG','1176');
INSERT INTO "geodetic_datum" VALUES('EPSG','1167','Bulgaria Geodetic System 2005',NULL,'EPSG','7019','EPSG','8901','2005-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13219','geodetic_datum','EPSG','1167','EPSG','1056','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1168','Geocentric Datum of Australia 2020',NULL,'EPSG','7019','EPSG','8901','2017-05-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13220','geodetic_datum','EPSG','1168','EPSG','4177','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1173','St. Helena Tritan',NULL,'EPSG','7030','EPSG','8901','2011-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13225','geodetic_datum','EPSG','1173','EPSG','3183','EPSG','1146');
INSERT INTO "geodetic_datum" VALUES('EPSG','1174','St. Helena Geodetic Datum 2015',NULL,'EPSG','7019','EPSG','8901','2015-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13226','geodetic_datum','EPSG','1174','EPSG','3183','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','1178','European Terrestrial Reference Frame 1989',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13230','geodetic_datum','EPSG','1178','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1179','European Terrestrial Reference Frame 1990',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13231','geodetic_datum','EPSG','1179','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1180','European Terrestrial Reference Frame 1991',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13232','geodetic_datum','EPSG','1180','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1181','European Terrestrial Reference Frame 1992',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13233','geodetic_datum','EPSG','1181','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1182','European Terrestrial Reference Frame 1993',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13234','geodetic_datum','EPSG','1182','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1183','European Terrestrial Reference Frame 1994',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13235','geodetic_datum','EPSG','1183','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1184','European Terrestrial Reference Frame 1996',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13236','geodetic_datum','EPSG','1184','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1185','European Terrestrial Reference Frame 1997',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13237','geodetic_datum','EPSG','1185','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1186','European Terrestrial Reference Frame 2000',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13238','geodetic_datum','EPSG','1186','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1187','Islands Net 2016',NULL,'EPSG','7019','EPSG','8901','2016-07-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13239','geodetic_datum','EPSG','1187','EPSG','1120','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1188','Gusterberg (Ferro)',NULL,'EPSG','1026','EPSG','8909','1817-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13240','geodetic_datum','EPSG','1188','EPSG','4455','EPSG','1028');
INSERT INTO "geodetic_datum" VALUES('EPSG','1189','St. Stephen (Ferro)',NULL,'EPSG','1026','EPSG','8909','1817-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13241','geodetic_datum','EPSG','1189','EPSG','4456','EPSG','1028');
INSERT INTO "geodetic_datum" VALUES('EPSG','1191','IGS14',NULL,'EPSG','7019','EPSG','8901','2010-01-01',2010.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13243','geodetic_datum','EPSG','1191','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1192','North American Datum of 1983 (CSRS96)',NULL,'EPSG','7019','EPSG','8901','1996-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13244','geodetic_datum','EPSG','1192','EPSG','1061','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1193','North American Datum of 1983 (CSRS) version 2',NULL,'EPSG','7019','EPSG','8901','1998-01-01',NULL,NULL,NULL,1997.0,0);
INSERT INTO "usage" VALUES('EPSG','13245','geodetic_datum','EPSG','1193','EPSG','1061','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1194','North American Datum of 1983 (CSRS) version 3',NULL,'EPSG','7019','EPSG','8901','1999-01-01',NULL,NULL,NULL,1997.0,0);
INSERT INTO "usage" VALUES('EPSG','13246','geodetic_datum','EPSG','1194','EPSG','1061','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1195','North American Datum of 1983 (CSRS) version 4',NULL,'EPSG','7019','EPSG','8901','2002-01-01',NULL,NULL,NULL,2002.0,0);
INSERT INTO "usage" VALUES('EPSG','13247','geodetic_datum','EPSG','1195','EPSG','1061','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1196','North American Datum of 1983 (CSRS) version 5',NULL,'EPSG','7019','EPSG','8901','2007-01-01',NULL,NULL,NULL,2006.0,0);
INSERT INTO "usage" VALUES('EPSG','13248','geodetic_datum','EPSG','1196','EPSG','1061','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1197','North American Datum of 1983 (CSRS) version 6',NULL,'EPSG','7019','EPSG','8901','2010-01-01',NULL,NULL,NULL,2010.0,0);
INSERT INTO "usage" VALUES('EPSG','13249','geodetic_datum','EPSG','1197','EPSG','1061','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1198','North American Datum of 1983 (CSRS) version 7',NULL,'EPSG','7019','EPSG','8901','2017-05-01',NULL,NULL,NULL,2010.0,0);
INSERT INTO "usage" VALUES('EPSG','13250','geodetic_datum','EPSG','1198','EPSG','1061','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1201','System of the Unified Trigonometrical Cadastral Network [JTSK03]',NULL,'EPSG','7004','EPSG','8901','2003-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13253','geodetic_datum','EPSG','1201','EPSG','1211','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1204','European Terrestrial Reference Frame 2005',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13256','geodetic_datum','EPSG','1204','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1206','European Terrestrial Reference Frame 2014',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13258','geodetic_datum','EPSG','1206','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1207','Macao 1920',NULL,'EPSG','7022','EPSG','8901','1920-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13259','geodetic_datum','EPSG','1207','EPSG','1147','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1208','Macao Geodetic Datum 2008',NULL,'EPSG','7019','EPSG','8901','2008-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13260','geodetic_datum','EPSG','1208','EPSG','1147','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1209','Hong Kong Geodetic',NULL,'EPSG','7019','EPSG','8901','1998-04-30',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13261','geodetic_datum','EPSG','1209','EPSG','1118','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1211','NAD83 (Federal Base Network)',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13263','geodetic_datum','EPSG','1211','EPSG','4515','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1212','NAD83 (High Accuracy Reference Network - Corrected)',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13264','geodetic_datum','EPSG','1212','EPSG','3634','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1214','Serbian Spatial Reference System 2000',NULL,'EPSG','7019','EPSG','8901','2010-08-19',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13266','geodetic_datum','EPSG','1214','EPSG','4543','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1217','Camacupa 2015',NULL,'EPSG','7012','EPSG','8901','2015-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13269','geodetic_datum','EPSG','1217','EPSG','1029','EPSG','1130');
INSERT INTO "geodetic_datum" VALUES('EPSG','1218','MOMRA Terrestrial Reference Frame 2000',NULL,'EPSG','7019','EPSG','8901','2004-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13270','geodetic_datum','EPSG','1218','EPSG','1206','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1220','Reference System de Angola 2013',NULL,'EPSG','7019','EPSG','8901','2015-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13272','geodetic_datum','EPSG','1220','EPSG','1029','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1221','North American Datum of 1983 (MARP00)',NULL,'EPSG','7019','EPSG','8901','1993-08-15',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13273','geodetic_datum','EPSG','1221','EPSG','4167','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1223','Reseau Geodesique de Wallis et Futuna 1996',NULL,'EPSG','7019','EPSG','8901','1996-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13275','geodetic_datum','EPSG','1223','EPSG','1255','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1225','CR-SIRGAS epoch 2014.59',NULL,'EPSG','7019','EPSG','8901','2018-04-17',NULL,NULL,NULL,2014.59,0);
INSERT INTO "usage" VALUES('EPSG','13277','geodetic_datum','EPSG','1225','EPSG','1074','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1227','SIRGAS Continuously Operating Network DGF00P01',NULL,'EPSG','7019','EPSG','8901','2000-05-01',2000.4,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13279','geodetic_datum','EPSG','1227','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1228','SIRGAS Continuously Operating Network DGF01P01',NULL,'EPSG','7019','EPSG','8901','2000-01-01',2000.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13280','geodetic_datum','EPSG','1228','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1229','SIRGAS Continuously Operating Network DGF01P02',NULL,'EPSG','7019','EPSG','8901','1998-05-01',1998.4,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13281','geodetic_datum','EPSG','1229','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1230','SIRGAS Continuously Operating Network DGF02P01',NULL,'EPSG','7019','EPSG','8901','2000-01-01',2000.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13282','geodetic_datum','EPSG','1230','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1231','SIRGAS Continuously Operating Network DGF04P01',NULL,'EPSG','7019','EPSG','8901','2003-01-01',2003.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13283','geodetic_datum','EPSG','1231','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1232','SIRGAS Continuously Operating Network DGF05P01',NULL,'EPSG','7019','EPSG','8901','2004-01-01',2004.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13284','geodetic_datum','EPSG','1232','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1233','SIRGAS Continuously Operating Network DGF06P01',NULL,'EPSG','7019','EPSG','8901','2004-01-01',2004.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13285','geodetic_datum','EPSG','1233','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1234','SIRGAS Continuously Operating Network DGF07P01',NULL,'EPSG','7019','EPSG','8901','2004-07-01',2004.5,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13286','geodetic_datum','EPSG','1234','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1235','SIRGAS Continuously Operating Network DGF08P01',NULL,'EPSG','7019','EPSG','8901','2004-07-01',2004.5,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13287','geodetic_datum','EPSG','1235','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1236','SIRGAS Continuously Operating Network SIR09P01',NULL,'EPSG','7019','EPSG','8901','2005-01-01',2005.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13288','geodetic_datum','EPSG','1236','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1237','SIRGAS Continuously Operating Network SIR10P01',NULL,'EPSG','7019','EPSG','8901','2005-01-01',2005.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13289','geodetic_datum','EPSG','1237','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1238','SIRGAS Continuously Operating Network SIR11P01',NULL,'EPSG','7019','EPSG','8901','2005-01-01',2005.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13290','geodetic_datum','EPSG','1238','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1239','SIRGAS Continuously Operating Network SIR13P01',NULL,'EPSG','7019','EPSG','8901','2012-01-01',2012.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13291','geodetic_datum','EPSG','1239','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1240','SIRGAS Continuously Operating Network SIR14P01',NULL,'EPSG','7019','EPSG','8901','2013-01-01',2013.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13292','geodetic_datum','EPSG','1240','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1241','SIRGAS Continuously Operating Network SIR15P01',NULL,'EPSG','7019','EPSG','8901','2013-01-01',2013.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13293','geodetic_datum','EPSG','1241','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1242','SIRGAS Continuously Operating Network SIR17P01',NULL,'EPSG','7019','EPSG','8901','2015-01-01',2015.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13294','geodetic_datum','EPSG','1242','EPSG','4530','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1243','SIRGAS-Chile realization 2 epoch 2010',NULL,'EPSG','7019','EPSG','8901','2010-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13295','geodetic_datum','EPSG','1243','EPSG','1066','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1244','IGS97',NULL,'EPSG','7019','EPSG','8901','1997-01-01',1997.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13296','geodetic_datum','EPSG','1244','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1245','IGS00',NULL,'EPSG','7019','EPSG','8901','1998-01-01',1998.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13297','geodetic_datum','EPSG','1245','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1246','IGb00',NULL,'EPSG','7019','EPSG','8901','1998-01-01',1998.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13298','geodetic_datum','EPSG','1246','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1247','IGS05',NULL,'EPSG','7019','EPSG','8901','2000-01-01',2000.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13299','geodetic_datum','EPSG','1247','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1248','IGb08',NULL,'EPSG','7019','EPSG','8901','2005-01-01',2005.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13300','geodetic_datum','EPSG','1248','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1249','North American Datum of 1983 (PACP00)',NULL,'EPSG','7019','EPSG','8901','1993-08-15',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13301','geodetic_datum','EPSG','1249','EPSG','4162','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1251','Kosovo Reference System 2001',NULL,'EPSG','7019','EPSG','8901','2001-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13303','geodetic_datum','EPSG','1251','EPSG','4542','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1252','SIRGAS-Chile realization 3 epoch 2013',NULL,'EPSG','7019','EPSG','8901','2013-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13304','geodetic_datum','EPSG','1252','EPSG','1066','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1253','SIRGAS-Chile realization 4 epoch 2016',NULL,'EPSG','7019','EPSG','8901','2016-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18458','geodetic_datum','EPSG','1253','EPSG','1066','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1254','SIRGAS-Chile',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13306','geodetic_datum','EPSG','1254','EPSG','1066','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1257','Tapi Aike',NULL,'EPSG','7022','EPSG','8901','1945-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13890','geodetic_datum','EPSG','1257','EPSG','4569','EPSG','1136');
INSERT INTO "geodetic_datum" VALUES('EPSG','1258','Ministerio de Marina Norte',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13891','geodetic_datum','EPSG','1258','EPSG','2357','EPSG','1136');
INSERT INTO "geodetic_datum" VALUES('EPSG','1259','Ministerio de Marina Sur',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13892','geodetic_datum','EPSG','1259','EPSG','2357','EPSG','1136');
INSERT INTO "geodetic_datum" VALUES('EPSG','1263','Oman National Geodetic Datum 2017',NULL,'EPSG','7019','EPSG','8901','2017-11-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13962','geodetic_datum','EPSG','1263','EPSG','1183','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1264','HS2 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','14026','geodetic_datum','EPSG','1264','EPSG','4582','EPSG','1260');
INSERT INTO "geodetic_datum" VALUES('EPSG','1266','TPEN11 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2011-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13980','geodetic_datum','EPSG','1266','EPSG','4583','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1268','Kingdom of Saudi Arabia Geodetic Reference Frame 2017',NULL,'EPSG','7019','EPSG','8901','2019-07-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13896','geodetic_datum','EPSG','1268','EPSG','1206','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1271','MML07 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2007-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13993','geodetic_datum','EPSG','1271','EPSG','4588','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1272','IGb14',NULL,'EPSG','7019','EPSG','8901','2010-01-01',2010.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13994','geodetic_datum','EPSG','1272','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1273','AbInvA96_2020 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2020-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13876','geodetic_datum','EPSG','1273','EPSG','4589','EPSG','1196');
INSERT INTO "geodetic_datum" VALUES('EPSG','1286','Pico de las Nieves 1968',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','14025','geodetic_datum','EPSG','1286','EPSG','3873','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1289','GBK19 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','14127','geodetic_datum','EPSG','1289','EPSG','4607','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1291','Australian Terrestrial Reference Frame 2014',NULL,'EPSG','7019','EPSG','8901','2020-01-01',2020.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','14133','geodetic_datum','EPSG','1291','EPSG','4177','EPSG','1267');
INSERT INTO "geodetic_datum" VALUES('EPSG','1293','Sistem Referensi Geospasial Indonesia 2013',NULL,'EPSG','7030','EPSG','8901','2012-01-01',2012.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','14148','geodetic_datum','EPSG','1293','EPSG','1122','EPSG','1266');
INSERT INTO "geodetic_datum" VALUES('EPSG','1295','Lyon Turin Ferroviaire 2004',NULL,'EPSG','7019','EPSG','8901','2005-07-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','14538','geodetic_datum','EPSG','1295','EPSG','4613','EPSG','1271');
INSERT INTO "geodetic_datum" VALUES('EPSG','1304','Red Geodesica Para Mineria en Chile',NULL,'EPSG','7019','EPSG','8901','2019-01-01',2019.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','15025','geodetic_datum','EPSG','1304','EPSG','1066','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1305','ETRF2000 Poland',NULL,'EPSG','7019','EPSG','8901','2012-11-15',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','15061','geodetic_datum','EPSG','1305','EPSG','1192','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','1308','EOS21 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2021-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','15312','geodetic_datum','EPSG','1308','EPSG','4620','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1309','World Geodetic System 1984 (G2139)',NULL,'EPSG','7030','EPSG','8901','2016-01-01',2016.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','16665','geodetic_datum','EPSG','1309','EPSG','1262','EPSG','1176');
INSERT INTO "geodetic_datum" VALUES('EPSG','1310','ECML14_NB Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2021-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','16494','geodetic_datum','EPSG','1310','EPSG','4621','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1311','EWR2 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2021-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','16506','geodetic_datum','EPSG','1311','EPSG','4622','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1312','Reseau Geodesique Francais 1993 v2',NULL,'EPSG','7019','EPSG','8901','2010-06-18',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','16636','geodetic_datum','EPSG','1312','EPSG','1096','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1313','Reseau Geodesique Francais 1993 v2b',NULL,'EPSG','7019','EPSG','8901','2021-01-05',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','16637','geodetic_datum','EPSG','1313','EPSG','1096','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1314','MRH21 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2021-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','16933','geodetic_datum','EPSG','1314','EPSG','4652','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1315','MOLDOR11 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2021-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','16950','geodetic_datum','EPSG','1315','EPSG','4655','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1317','HULLEE13 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','17416','geodetic_datum','EPSG','1317','EPSG','4663','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1319','EBBWV14 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','17343','geodetic_datum','EPSG','1319','EPSG','4661','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1320','SCM22 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','17437','geodetic_datum','EPSG','1320','EPSG','4665','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1321','FNL22 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','17450','geodetic_datum','EPSG','1321','EPSG','4664','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1322','International Terrestrial Reference Frame 2020',NULL,'EPSG','7019','EPSG','8901','2015-01-01',2015.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','17903','geodetic_datum','EPSG','1322','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1324','MWC18 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18330','geodetic_datum','EPSG','1324','EPSG','4666','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1327','SIRGAS-Chile realization 5 epoch 2021',NULL,'EPSG','7019','EPSG','8901','2021-08-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18453','geodetic_datum','EPSG','1327','EPSG','1066','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1329','Marco Geocentrico Nacional de Referencia 2018',NULL,'EPSG','7019','EPSG','8901','2018-06-08',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18473','geodetic_datum','EPSG','1329','EPSG','1070','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1332','System 34 Jylland Intermediate Datum',NULL,'EPSG','7022','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19781','geodetic_datum','EPSG','1332','EPSG','2531','EPSG','1203');
INSERT INTO "geodetic_datum" VALUES('EPSG','1333','IGS20',NULL,'EPSG','7019','EPSG','8901','2015-01-01',2015.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18632','geodetic_datum','EPSG','1333','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1334','DoPw22 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18851','geodetic_datum','EPSG','1334','EPSG','4686','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1335','ShAb07 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18853','geodetic_datum','EPSG','1335','EPSG','4687','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1336','CNH22 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2021-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18690','geodetic_datum','EPSG','1336','EPSG','4677','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1337','System 34 Sjaelland Intermediate Datum',NULL,'EPSG','7022','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19782','geodetic_datum','EPSG','1337','EPSG','2532','EPSG','1203');
INSERT INTO "geodetic_datum" VALUES('EPSG','1338','CWS13 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18702','geodetic_datum','EPSG','1338','EPSG','4678','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1339','DIBA15 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18768','geodetic_datum','EPSG','1339','EPSG','4681','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1340','GWPBS22 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18715','geodetic_datum','EPSG','1340','EPSG','4685','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1341','GWWAB22 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18725','geodetic_datum','EPSG','1341','EPSG','4684','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1342','GWWWA22 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18732','geodetic_datum','EPSG','1342','EPSG','4683','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1343','MALS09 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18740','geodetic_datum','EPSG','1343','EPSG','4682','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1344','OxWo08 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18783','geodetic_datum','EPSG','1344','EPSG','4680','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1345','SYC20 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18756','geodetic_datum','EPSG','1345','EPSG','4679','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1346','System 45 Bornholm Intermediate Datum',NULL,'EPSG','7022','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19715','geodetic_datum','EPSG','1346','EPSG','2533','EPSG','1203');
INSERT INTO "geodetic_datum" VALUES('EPSG','1347','Generalstabens System Intermediate Datum',NULL,'EPSG','7051','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19716','geodetic_datum','EPSG','1347','EPSG','4575','EPSG','1203');
INSERT INTO "geodetic_datum" VALUES('EPSG','1348','Generalstabens System Bornholm Intermediate Datum',NULL,'EPSG','7051','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19717','geodetic_datum','EPSG','1348','EPSG','2533','EPSG','1203');
INSERT INTO "geodetic_datum" VALUES('EPSG','1349','Copenhagen Commune Intermediate Datum',NULL,'EPSG','7051','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19718','geodetic_datum','EPSG','1349','EPSG','4693','EPSG','1203');
INSERT INTO "geodetic_datum" VALUES('EPSG','1350','Ostenfeld  Intermediate Datum',NULL,'EPSG','7004','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19719','geodetic_datum','EPSG','1350','EPSG','4694','EPSG','1203');
INSERT INTO "geodetic_datum" VALUES('EPSG','1351','SMITB20 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19174','geodetic_datum','EPSG','1351','EPSG','4688','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1352','RBEPP12 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2022-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19180','geodetic_datum','EPSG','1352','EPSG','4689','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1353','ETRS89/DREF91 Realization 2016',NULL,'EPSG','7019','EPSG','8901','2016-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19242','geodetic_datum','EPSG','1353','EPSG','1103','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1355','Sonatrach Reference Frame 2020',NULL,'EPSG','7019','EPSG','8901','2012-11-15',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19535','geodetic_datum','EPSG','1355','EPSG','1026','EPSG','1136');
INSERT INTO "geodetic_datum" VALUES('EPSG','1356','Latvian coordinate system 2020',NULL,'EPSG','7019','EPSG','8901','2023-01-01',NULL,NULL,NULL,2020.28,0);
INSERT INTO "usage" VALUES('EPSG','19558','geodetic_datum','EPSG','1356','EPSG','1139','EPSG','1026');
INSERT INTO "geodetic_datum" VALUES('EPSG','1357','Reseau Geodesique de Nouvelle Caledonie 2015',NULL,'EPSG','7019','EPSG','8901','2016-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19600','geodetic_datum','EPSG','1357','EPSG','1174','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1358','BH_ETRS89',NULL,'EPSG','7019','EPSG','8901','2011-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19740','geodetic_datum','EPSG','1358','EPSG','1050','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1359','Hughes 1980',NULL,'EPSG','7058','EPSG','8901','1980-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19883','geodetic_datum','EPSG','1359','EPSG','1262','EPSG','1110');
INSERT INTO "geodetic_datum" VALUES('EPSG','1360','NSIDC International 1924 Authalic Sphere',NULL,'EPSG','7057','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','19879','geodetic_datum','EPSG','1360','EPSG','1262','EPSG','1195');
INSERT INTO "geodetic_datum" VALUES('EPSG','1365','North American Datum of 1983 (CSRS) version 8',NULL,'EPSG','7019','EPSG','8901','2022-11-27',NULL,NULL,NULL,2010.0,0);
INSERT INTO "usage" VALUES('EPSG','20140','geodetic_datum','EPSG','1365','EPSG','1061','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1366','COV23 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2023-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','20309','geodetic_datum','EPSG','1366','EPSG','4743','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1367','Brenner Base Tunnel 2000',NULL,'EPSG','7030','EPSG','8901','2000-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','20337','geodetic_datum','EPSG','1367','EPSG','4744','EPSG','1285');
INSERT INTO "geodetic_datum" VALUES('EPSG','1379','Saba',NULL,'EPSG','7022','EPSG','8901','2023-04-05',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22072','geodetic_datum','EPSG','1379','EPSG','4757','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','1380','BES2020 Saba',NULL,'EPSG','7019','EPSG','8901','2023-04-05',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','21849','geodetic_datum','EPSG','1380','EPSG','4757','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1382','European Terrestrial Reference Frame 2020',NULL,'EPSG','7019','EPSG','8901','1989-01-01',1989.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','21225','geodetic_datum','EPSG','1382','EPSG','1298','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1383','World Geodetic System 1984 (G2296)',NULL,'EPSG','7030','EPSG','8901','2024-01-01',2024.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','21254','geodetic_datum','EPSG','1383','EPSG','1262','EPSG','1176');
INSERT INTO "geodetic_datum" VALUES('EPSG','1385','ECML14 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2024-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','21397','geodetic_datum','EPSG','1385','EPSG','4774','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1386','WC05 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2024-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','21396','geodetic_datum','EPSG','1386','EPSG','4775','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1389','Mayotte Geodetic Reference Frame 2023',NULL,'EPSG','7019','EPSG','8901','2024-07-08',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','21858','geodetic_datum','EPSG','1389','EPSG','1159','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1391','EUREF-FIN',NULL,'EPSG','7019','EPSG','8901','1999-01-01',NULL,NULL,NULL,1997.0,0);
INSERT INTO "usage" VALUES('EPSG','21991','geodetic_datum','EPSG','1391','EPSG','1095','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1392','Uzbekistan Geodetic Datum 2024',NULL,'EPSG','7019','EPSG','8901','2024-07-04',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22194','geodetic_datum','EPSG','1392','EPSG','1248','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1393','Sint Eustatius',NULL,'EPSG','7022','EPSG','8901','2023-04-05',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22279','geodetic_datum','EPSG','1393','EPSG','4788','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','1394','BES2020 Sint Eustatius',NULL,'EPSG','7019','EPSG','8901','2023-04-05',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22280','geodetic_datum','EPSG','1394','EPSG','4788','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1396','Bonaire',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22166','geodetic_datum','EPSG','1396','EPSG','3822','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','1397','Bonaire 2004',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22170','geodetic_datum','EPSG','1397','EPSG','3822','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','1399','International Terrestrial Reference Frame 2020-u2023',NULL,'EPSG','7019','EPSG','8901','2015-01-01',2015.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22373','geodetic_datum','EPSG','1399','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1400','IGb20',NULL,'EPSG','7019','EPSG','8901','2015-01-01',2015.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22362','geodetic_datum','EPSG','1400','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1401','Uganda Geodetic Reference Frame',NULL,'EPSG','7019','EPSG','8901','March 2011',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22456','geodetic_datum','EPSG','1401','EPSG','1241','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1402','Liberia Reference Frame 2021',NULL,'EPSG','7019','EPSG','8901','2022-10-31',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22451','geodetic_datum','EPSG','1402','EPSG','1142','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1403','Nordic Geodetic Commission ETRF14',NULL,'EPSG','7019','EPSG','8901','2023-05-15',NULL,NULL,NULL,2000.0,0);
INSERT INTO "usage" VALUES('EPSG','23987','geodetic_datum','EPSG','1403','EPSG','4795','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1404','Georgia Geodetic Datum',NULL,'EPSG','7019','EPSG','8901','2013-11-14',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22791','geodetic_datum','EPSG','1404','EPSG','1102','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1405','EWR3 Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2024-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22755','geodetic_datum','EPSG','1405','EPSG','4799','EPSG','1141');
INSERT INTO "geodetic_datum" VALUES('EPSG','1406','WSPG Intermediate Reference Frame',NULL,'EPSG','7019','EPSG','8901','2025-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','22831','geodetic_datum','EPSG','1406','EPSG','4801','EPSG','1293');
INSERT INTO "geodetic_datum" VALUES('EPSG','1407','ETRS89-NOR [EUREF89]',NULL,'EPSG','7019','EPSG','8901','1999-01-01',NULL,NULL,NULL,1995.0,0);
INSERT INTO "usage" VALUES('EPSG','23762','geodetic_datum','EPSG','1407','EPSG','1182','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','1412','ETRS89-DNK',NULL,'EPSG','7019','EPSG','8901','2019-01-01',NULL,NULL,NULL,2015.829,0);
INSERT INTO "usage" VALUES('EPSG','23440','geodetic_datum','EPSG','1412','EPSG','1080','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1413','Asse geodetic datum 2025',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','23487','geodetic_datum','EPSG','1413','EPSG','4805','EPSG','1144');
INSERT INTO "geodetic_datum" VALUES('EPSG','1414','California Spatial Reference Network epoch 2025.0 (NAD83 2011)',NULL,'EPSG','7019','EPSG','8901','2025-06-15',NULL,NULL,NULL,2025.0,0);
INSERT INTO "usage" VALUES('EPSG','23587','geodetic_datum','EPSG','1414','EPSG','1375','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1417','Kazakhstan Terrestrial Reference Frame 2023',NULL,'EPSG','7019','EPSG','8901','2025-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','23414','geodetic_datum','EPSG','1417','EPSG','1131','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1418','California Spatial Reference Network epoch 2025.0 (ITRF2020) ',NULL,'EPSG','7019','EPSG','8901','2025-06-15',NULL,NULL,NULL,2025.0,0);
INSERT INTO "usage" VALUES('EPSG','23566','geodetic_datum','EPSG','1418','EPSG','1375','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1419','Greenland Reference 1996 (2021)',NULL,'EPSG','7019','EPSG','8901','2025-07-01',NULL,NULL,NULL,1996.62,0);
INSERT INTO "usage" VALUES('EPSG','23455','geodetic_datum','EPSG','1419','EPSG','1107','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1420','Greenland Reference 1996 (1996)',NULL,'EPSG','7019','EPSG','8901','1996-08-14',NULL,NULL,NULL,1996.62,0);
INSERT INTO "usage" VALUES('EPSG','23616','geodetic_datum','EPSG','1420','EPSG','1107','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1422','North American Terrestrial Reference Frame of 2022',NULL,'EPSG','7019','EPSG','8901','2025-06-16',NULL,NULL,NULL,2020.0,0);
INSERT INTO "usage" VALUES('EPSG','23622','geodetic_datum','EPSG','1422','EPSG','4803','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','1428','CR-SIRGAS epoch 2019.24',NULL,'EPSG','7019','EPSG','8901','2020-09-04',NULL,NULL,NULL,2019.24,0);
INSERT INTO "usage" VALUES('EPSG','24187','geodetic_datum','EPSG','1428','EPSG','1074','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6001','Not specified (based on Airy 1830 ellipsoid)',NULL,'EPSG','7001','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13422','geodetic_datum','EPSG','6001','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6002','Not specified (based on Airy Modified 1849 ellipsoid)',NULL,'EPSG','7002','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13423','geodetic_datum','EPSG','6002','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6003','Not specified (based on Australian National Spheroid)',NULL,'EPSG','7003','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13424','geodetic_datum','EPSG','6003','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6004','Not specified (based on Bessel 1841 ellipsoid)',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13425','geodetic_datum','EPSG','6004','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6005','Not specified (based on Bessel Modified ellipsoid)',NULL,'EPSG','7005','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13426','geodetic_datum','EPSG','6005','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6006','Not specified (based on Bessel Namibia ellipsoid)',NULL,'EPSG','7046','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13427','geodetic_datum','EPSG','6006','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6007','Not specified (based on Clarke 1858 ellipsoid)',NULL,'EPSG','7007','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13428','geodetic_datum','EPSG','6007','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6008','Not specified (based on Clarke 1866 ellipsoid)',NULL,'EPSG','7008','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13429','geodetic_datum','EPSG','6008','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6009','Not specified (based on Clarke 1866 Michigan ellipsoid)',NULL,'EPSG','7009','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13430','geodetic_datum','EPSG','6009','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6010','Not specified (based on Clarke 1880 (Benoit) ellipsoid)',NULL,'EPSG','7010','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13431','geodetic_datum','EPSG','6010','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6011','Not specified (based on Clarke 1880 (IGN) ellipsoid)',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13432','geodetic_datum','EPSG','6011','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6012','Not specified (based on Clarke 1880 (RGS) ellipsoid)',NULL,'EPSG','7012','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13433','geodetic_datum','EPSG','6012','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6013','Not specified (based on Clarke 1880 (Arc) ellipsoid)',NULL,'EPSG','7013','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13434','geodetic_datum','EPSG','6013','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6014','Not specified (based on Clarke 1880 (SGA 1922) ellipsoid)',NULL,'EPSG','7014','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13435','geodetic_datum','EPSG','6014','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6015','Not specified (based on Everest 1830 (1937 Adjustment) ellipsoid)',NULL,'EPSG','7015','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13436','geodetic_datum','EPSG','6015','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6016','Not specified (based on Everest 1830 (1967 Definition) ellipsoid)',NULL,'EPSG','7016','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13437','geodetic_datum','EPSG','6016','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6018','Not specified (based on Everest 1830 Modified ellipsoid)',NULL,'EPSG','7018','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13438','geodetic_datum','EPSG','6018','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6019','Not specified (based on GRS 1980 ellipsoid)',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13439','geodetic_datum','EPSG','6019','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6020','Not specified (based on Helmert 1906 ellipsoid)',NULL,'EPSG','7020','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13440','geodetic_datum','EPSG','6020','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6021','Not specified (based on Indonesian National Spheroid)',NULL,'EPSG','7021','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13441','geodetic_datum','EPSG','6021','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6022','Not specified (based on International 1924 ellipsoid)',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13442','geodetic_datum','EPSG','6022','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6024','Not specified (based on Krassowsky 1940 ellipsoid)',NULL,'EPSG','7024','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13443','geodetic_datum','EPSG','6024','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6025','Not specified (based on NWL 9D ellipsoid)',NULL,'EPSG','7025','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13444','geodetic_datum','EPSG','6025','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6027','Not specified (based on Plessis 1817 ellipsoid)',NULL,'EPSG','7027','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13445','geodetic_datum','EPSG','6027','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6028','Not specified (based on Struve 1860 ellipsoid)',NULL,'EPSG','7028','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13446','geodetic_datum','EPSG','6028','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6029','Not specified (based on War Office ellipsoid)',NULL,'EPSG','7029','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13447','geodetic_datum','EPSG','6029','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6030','Not specified (based on WGS 84 ellipsoid)',NULL,'EPSG','7030','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13448','geodetic_datum','EPSG','6030','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6031','Not specified (based on GEM 10C ellipsoid)',NULL,'EPSG','7031','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13449','geodetic_datum','EPSG','6031','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6032','Not specified (based on OSU86F ellipsoid)',NULL,'EPSG','7032','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13450','geodetic_datum','EPSG','6032','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6033','Not specified (based on OSU91A ellipsoid)',NULL,'EPSG','7033','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13451','geodetic_datum','EPSG','6033','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6034','Not specified (based on Clarke 1880 ellipsoid)',NULL,'EPSG','7034','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13452','geodetic_datum','EPSG','6034','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6035','Not specified (based on Authalic Sphere)',NULL,'EPSG','7035','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13453','geodetic_datum','EPSG','6035','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6036','Not specified (based on GRS 1967 ellipsoid)',NULL,'EPSG','7036','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13454','geodetic_datum','EPSG','6036','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6041','Not specified (based on Average Terrestrial System 1977 ellipsoid)',NULL,'EPSG','7041','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13455','geodetic_datum','EPSG','6041','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6042','Not specified (based on Everest (1830 Definition) ellipsoid)',NULL,'EPSG','7042','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13456','geodetic_datum','EPSG','6042','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6043','Not specified (based on WGS 72 ellipsoid)',NULL,'EPSG','7043','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13457','geodetic_datum','EPSG','6043','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6044','Not specified (based on Everest 1830 (1962 Definition) ellipsoid)',NULL,'EPSG','7044','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13458','geodetic_datum','EPSG','6044','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6045','Not specified (based on Everest 1830 (1975 Definition) ellipsoid)',NULL,'EPSG','7045','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13459','geodetic_datum','EPSG','6045','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6047','Not specified (based on GRS 1980 Authalic Sphere)',NULL,'EPSG','7048','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13460','geodetic_datum','EPSG','6047','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6052','Not specified (based on Clarke 1866 Authalic Sphere)',NULL,'EPSG','7052','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13461','geodetic_datum','EPSG','6052','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6053','Not specified (based on International 1924 Authalic Sphere)',NULL,'EPSG','7057','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13462','geodetic_datum','EPSG','6053','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6054','Not specified (based on Hughes 1980 ellipsoid)',NULL,'EPSG','7058','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13463','geodetic_datum','EPSG','6054','EPSG','1263','EPSG','1213');
INSERT INTO "geodetic_datum" VALUES('EPSG','6055','Popular Visualisation Datum',NULL,'EPSG','7059','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13464','geodetic_datum','EPSG','6055','EPSG','1262','EPSG','1098');
INSERT INTO "geodetic_datum" VALUES('EPSG','6120','Greek',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13465','geodetic_datum','EPSG','6120','EPSG','3254','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6121','Greek Geodetic Reference System 1987',NULL,'EPSG','7019','EPSG','8901','1987-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13466','geodetic_datum','EPSG','6121','EPSG','3254','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6122','Average Terrestrial System 1977',NULL,'EPSG','7041','EPSG','8901','1977-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13467','geodetic_datum','EPSG','6122','EPSG','1283','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6123','Kartastokoordinaattijarjestelma (1966)',NULL,'EPSG','7022','EPSG','8901','1966-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13468','geodetic_datum','EPSG','6123','EPSG','3333','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6124','Rikets koordinatsystem 1990',NULL,'EPSG','7004','EPSG','8901','1990-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13469','geodetic_datum','EPSG','6124','EPSG','1225','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6125','Samboja',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13470','geodetic_datum','EPSG','6125','EPSG','1328','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6126','Lithuania 1994 (ETRS89)',NULL,'EPSG','7019','EPSG','8901','1992-10-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13471','geodetic_datum','EPSG','6126','EPSG','1145','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6127','Tete',NULL,'EPSG','7008','EPSG','8901','1960-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13472','geodetic_datum','EPSG','6127','EPSG','3281','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6128','Madzansua',NULL,'EPSG','7008','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13473','geodetic_datum','EPSG','6128','EPSG','1315','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6129','Observatario',NULL,'EPSG','7008','EPSG','8901','1907-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13474','geodetic_datum','EPSG','6129','EPSG','1329','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6130','Moznet (ITRF94)',NULL,'EPSG','7030','EPSG','8901','1996-11-24',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13475','geodetic_datum','EPSG','6130','EPSG','1167','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6131','Indian 1960',NULL,'EPSG','7015','EPSG','8901','1960-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13476','geodetic_datum','EPSG','6131','EPSG','4007','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6132','Final Datum 1958',NULL,'EPSG','7012','EPSG','8901','1958-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13477','geodetic_datum','EPSG','6132','EPSG','1300','EPSG','1216');
INSERT INTO "geodetic_datum" VALUES('EPSG','6133','Estonia 1992',NULL,'EPSG','7019','EPSG','8901','1992-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13478','geodetic_datum','EPSG','6133','EPSG','3246','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6134','PDO Survey Datum 1993',NULL,'EPSG','7012','EPSG','8901','1993-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13479','geodetic_datum','EPSG','6134','EPSG','3288','EPSG','1216');
INSERT INTO "geodetic_datum" VALUES('EPSG','6135','Old Hawaiian',NULL,'EPSG','7008','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13480','geodetic_datum','EPSG','6135','EPSG','1334','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6136','St. Lawrence Island',NULL,'EPSG','7008','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13481','geodetic_datum','EPSG','6136','EPSG','1332','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6137','St. Paul Island',NULL,'EPSG','7008','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13482','geodetic_datum','EPSG','6137','EPSG','1333','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6138','St. George Island',NULL,'EPSG','7008','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13483','geodetic_datum','EPSG','6138','EPSG','1331','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6139','Puerto Rico',NULL,'EPSG','7008','EPSG','8901','1901-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13484','geodetic_datum','EPSG','6139','EPSG','1335','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6140','NAD83 Canadian Spatial Reference System',NULL,'EPSG','7019','EPSG','8901','1998-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13485','geodetic_datum','EPSG','6140','EPSG','1061','EPSG','1189');
INSERT INTO "geodetic_datum" VALUES('EPSG','6141','Israel 1993',NULL,'EPSG','7019','EPSG','8901','1993-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13486','geodetic_datum','EPSG','6141','EPSG','2603','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6142','Locodjo 1965',NULL,'EPSG','7012','EPSG','8901','1965-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13487','geodetic_datum','EPSG','6142','EPSG','1075','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6143','Abidjan 1987',NULL,'EPSG','7012','EPSG','8901','1987-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13488','geodetic_datum','EPSG','6143','EPSG','1075','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6144','Kalianpur 1937',NULL,'EPSG','7015','EPSG','8901','1937-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13489','geodetic_datum','EPSG','6144','EPSG','1308','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6145','Kalianpur 1962',NULL,'EPSG','7044','EPSG','8901','1962-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13490','geodetic_datum','EPSG','6145','EPSG','1184','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6146','Kalianpur 1975',NULL,'EPSG','7045','EPSG','8901','1975-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13491','geodetic_datum','EPSG','6146','EPSG','3341','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6147','Hanoi 1972',NULL,'EPSG','7024','EPSG','8901','1972-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13492','geodetic_datum','EPSG','6147','EPSG','3328','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6148','Hartebeesthoek94',NULL,'EPSG','7030','EPSG','8901','1994-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13493','geodetic_datum','EPSG','6148','EPSG','4540','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6149','CH1903',NULL,'EPSG','7004','EPSG','8901','1903-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13494','geodetic_datum','EPSG','6149','EPSG','1286','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6150','CH1903+',NULL,'EPSG','7004','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13495','geodetic_datum','EPSG','6150','EPSG','1286','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6151','Swiss Terrestrial Reference System 1995',NULL,'EPSG','7019','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13496','geodetic_datum','EPSG','6151','EPSG','1286','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6152','NAD83 (High Accuracy Reference Network)',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13497','geodetic_datum','EPSG','6152','EPSG','1337','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6153','Rassadiran',NULL,'EPSG','7022','EPSG','8901','1998-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13498','geodetic_datum','EPSG','6153','EPSG','1338','EPSG','1216');
INSERT INTO "geodetic_datum" VALUES('EPSG','6154','European Datum 1950(1977)',NULL,'EPSG','7022','EPSG','8901','1977-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13499','geodetic_datum','EPSG','6154','EPSG','1123','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6155','Dabola 1981',NULL,'EPSG','7011','EPSG','8901','1981-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13500','geodetic_datum','EPSG','6155','EPSG','3257','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6156','System of the Unified Trigonometrical Cadastral Network',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13501','geodetic_datum','EPSG','6156','EPSG','1306','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6157','Mount Dillon',NULL,'EPSG','7007','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13502','geodetic_datum','EPSG','6157','EPSG','1322','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6158','Naparima 1955',NULL,'EPSG','7022','EPSG','8901','1955-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13503','geodetic_datum','EPSG','6158','EPSG','3143','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6159','European Libyan Datum 1979',NULL,'EPSG','7022','EPSG','8901','1979-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13504','geodetic_datum','EPSG','6159','EPSG','1143','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6160','Chos Malal 1914',NULL,'EPSG','7022','EPSG','8901','1914-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13505','geodetic_datum','EPSG','6160','EPSG','4562','EPSG','1216');
INSERT INTO "geodetic_datum" VALUES('EPSG','6161','Pampa del Castillo',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13506','geodetic_datum','EPSG','6161','EPSG','4563','EPSG','1216');
INSERT INTO "geodetic_datum" VALUES('EPSG','6162','Korean Datum 1985',NULL,'EPSG','7004','EPSG','8901','1985-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13507','geodetic_datum','EPSG','6162','EPSG','3266','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6163','Yemen National Geodetic Network 1996',NULL,'EPSG','7030','EPSG','8901','1996-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13508','geodetic_datum','EPSG','6163','EPSG','1257','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6164','South Yemen',NULL,'EPSG','7024','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13509','geodetic_datum','EPSG','6164','EPSG','1340','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6165','Bissau',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13510','geodetic_datum','EPSG','6165','EPSG','3258','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6166','Korean Datum 1995',NULL,'EPSG','7030','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13511','geodetic_datum','EPSG','6166','EPSG','3266','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6167','New Zealand Geodetic Datum 2000',NULL,'EPSG','7019','EPSG','8901','2007-11-16',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13512','geodetic_datum','EPSG','6167','EPSG','1175','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6168','Accra',NULL,'EPSG','7029','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13513','geodetic_datum','EPSG','6168','EPSG','1104','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6169','American Samoa 1962',NULL,'EPSG','7008','EPSG','8901','1962-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13514','geodetic_datum','EPSG','6169','EPSG','3109','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6170','Sistema de Referencia Geocentrico para America del Sur 1995',NULL,'EPSG','7019','EPSG','8901','1995-05-26',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13515','geodetic_datum','EPSG','6170','EPSG','3448','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6171','Reseau Geodesique Francais 1993 v1',NULL,'EPSG','7019','EPSG','8901','1993-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13516','geodetic_datum','EPSG','6171','EPSG','1096','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6172','Posiciones Geodesicas Argentinas',NULL,'EPSG','7019','EPSG','8901','1994-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13517','geodetic_datum','EPSG','6172','EPSG','1033','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6173','IRENET95',NULL,'EPSG','7019','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13518','geodetic_datum','EPSG','6173','EPSG','1305','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6174','Sierra Leone Colony 1924',NULL,'EPSG','7029','EPSG','8901','1924-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13519','geodetic_datum','EPSG','6174','EPSG','1342','EPSG','1142');
INSERT INTO "geodetic_datum" VALUES('EPSG','6175','Sierra Leone 1968',NULL,'EPSG','7012','EPSG','8901','1968-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13520','geodetic_datum','EPSG','6175','EPSG','3306','EPSG','1142');
INSERT INTO "geodetic_datum" VALUES('EPSG','6176','Australian Antarctic Datum 1998',NULL,'EPSG','7019','EPSG','8901','1998-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13521','geodetic_datum','EPSG','6176','EPSG','1278','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6178','Pulkovo 1942(83)',NULL,'EPSG','7024','EPSG','8901','1983-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13522','geodetic_datum','EPSG','6178','EPSG','3900','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6179','Pulkovo 1942(58)',NULL,'EPSG','7024','EPSG','8901','1958-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13523','geodetic_datum','EPSG','6179','EPSG','3574','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6180','Estonia 1997',NULL,'EPSG','7019','EPSG','8901','1997-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13524','geodetic_datum','EPSG','6180','EPSG','1090','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6181','Luxembourg Reference Frame',NULL,'EPSG','7022','EPSG','8901','1930-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13525','geodetic_datum','EPSG','6181','EPSG','1146','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6182','Azores Occidental Islands 1939',NULL,'EPSG','7022','EPSG','8901','1939-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13526','geodetic_datum','EPSG','6182','EPSG','1344','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6183','Azores Central Islands 1948',NULL,'EPSG','7022','EPSG','8901','1948-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13527','geodetic_datum','EPSG','6183','EPSG','1301','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6184','Azores Oriental Islands 1940',NULL,'EPSG','7022','EPSG','8901','1940-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13528','geodetic_datum','EPSG','6184','EPSG','1345','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6185','Madeira 1936',NULL,'EPSG','7022','EPSG','8901','1936-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13529','geodetic_datum','EPSG','6185','EPSG','1314','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6188','OSNI 1952',NULL,'EPSG','7001','EPSG','8901','1952-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13530','geodetic_datum','EPSG','6188','EPSG','2530','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6189','Red Geodesica Venezolana',NULL,'EPSG','7019','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13531','geodetic_datum','EPSG','6189','EPSG','1251','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6190','Posiciones Geodesicas Argentinas 1998',NULL,'EPSG','7019','EPSG','8901','1998-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13532','geodetic_datum','EPSG','6190','EPSG','1033','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6191','Albanian 1987',NULL,'EPSG','7024','EPSG','8901','1987-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13533','geodetic_datum','EPSG','6191','EPSG','3212','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6192','Douala 1948',NULL,'EPSG','7022','EPSG','8901','1948-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13534','geodetic_datum','EPSG','6192','EPSG','2555','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6193','Manoca 1962',NULL,'EPSG','7011','EPSG','8901','1962-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13535','geodetic_datum','EPSG','6193','EPSG','2555','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6194','Qoornoq 1927',NULL,'EPSG','7022','EPSG','8901','1927-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13536','geodetic_datum','EPSG','6194','EPSG','3362','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6195','Scoresbysund 1952',NULL,'EPSG','7022','EPSG','8901','1952-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13537','geodetic_datum','EPSG','6195','EPSG','2570','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6196','Ammassalik 1958',NULL,'EPSG','7022','EPSG','8901','1958-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13538','geodetic_datum','EPSG','6196','EPSG','2571','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6197','Garoua',NULL,'EPSG','7012','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13539','geodetic_datum','EPSG','6197','EPSG','2590','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6198','Kousseri',NULL,'EPSG','7012','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13540','geodetic_datum','EPSG','6198','EPSG','2591','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6199','Egypt 1930',NULL,'EPSG','7022','EPSG','8901','1930-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13541','geodetic_datum','EPSG','6199','EPSG','3242','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6200','Pulkovo 1995',NULL,'EPSG','7024','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13542','geodetic_datum','EPSG','6200','EPSG','1198','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6201','Adindan',NULL,'EPSG','7012','EPSG','8901','1958-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13543','geodetic_datum','EPSG','6201','EPSG','1271','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6202','Australian Geodetic Datum 1966',NULL,'EPSG','7003','EPSG','8901','1968-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13544','geodetic_datum','EPSG','6202','EPSG','1279','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6203','Australian Geodetic Datum 1984',NULL,'EPSG','7003','EPSG','8901','1985-12-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13545','geodetic_datum','EPSG','6203','EPSG','2576','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6204','Ain el Abd 1970',NULL,'EPSG','7022','EPSG','8901','1970-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13546','geodetic_datum','EPSG','6204','EPSG','1272','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6205','Afgooye',NULL,'EPSG','7024','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13547','geodetic_datum','EPSG','6205','EPSG','3308','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6206','Agadez',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13548','geodetic_datum','EPSG','6206','EPSG','1177','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6207','Lisbon 1937',NULL,'EPSG','7022','EPSG','8901','1937-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13549','geodetic_datum','EPSG','6207','EPSG','1294','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6208','Aratu',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13550','geodetic_datum','EPSG','6208','EPSG','1274','EPSG','1216');
INSERT INTO "geodetic_datum" VALUES('EPSG','6209','Arc 1950',NULL,'EPSG','7013','EPSG','8901','1950-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13551','geodetic_datum','EPSG','6209','EPSG','1276','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6210','Arc 1960',NULL,'EPSG','7012','EPSG','8901','1960-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13552','geodetic_datum','EPSG','6210','EPSG','1277','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6211','Batavia',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13553','geodetic_datum','EPSG','6211','EPSG','3666','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6212','Barbados 1938',NULL,'EPSG','7012','EPSG','8901','1938-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13554','geodetic_datum','EPSG','6212','EPSG','3218','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6213','Beduaram',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13555','geodetic_datum','EPSG','6213','EPSG','2771','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6214','Beijing 1954',NULL,'EPSG','7024','EPSG','8901','1954-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13556','geodetic_datum','EPSG','6214','EPSG','1067','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6215','Reseau National Belge 1950',NULL,'EPSG','7022','EPSG','8901','1950-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13557','geodetic_datum','EPSG','6215','EPSG','1347','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6216','Bermuda 1957',NULL,'EPSG','7008','EPSG','8901','1957-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13558','geodetic_datum','EPSG','6216','EPSG','3221','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6218','Bogota 1975',NULL,'EPSG','7022','EPSG','8901','1975-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13559','geodetic_datum','EPSG','6218','EPSG','3686','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6219','Bukit Rimpah',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13560','geodetic_datum','EPSG','6219','EPSG','1287','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6220','Camacupa 1948',NULL,'EPSG','7012','EPSG','8901','1948-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13561','geodetic_datum','EPSG','6220','EPSG','1288','EPSG','1104');
INSERT INTO "geodetic_datum" VALUES('EPSG','6221','Campo Inchauspe',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13562','geodetic_datum','EPSG','6221','EPSG','3843','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6222','Cape',NULL,'EPSG','7013','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13563','geodetic_datum','EPSG','6222','EPSG','1290','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6223','Carthage',NULL,'EPSG','7011','EPSG','8901','1925-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13564','geodetic_datum','EPSG','6223','EPSG','1236','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6224','Chua',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13565','geodetic_datum','EPSG','6224','EPSG','3356','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6225','Corrego Alegre 1970-72',NULL,'EPSG','7022','EPSG','8901','1972-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13566','geodetic_datum','EPSG','6225','EPSG','1293','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6226','Cote d''Ivoire',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13567','geodetic_datum','EPSG','6226','EPSG','1075','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6227','Deir ez Zor',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13568','geodetic_datum','EPSG','6227','EPSG','1623','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6228','Douala',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13569','geodetic_datum','EPSG','6228','EPSG','1060','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6229','Egypt 1907',NULL,'EPSG','7020','EPSG','8901','1907-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13570','geodetic_datum','EPSG','6229','EPSG','1086','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6230','European Datum 1950',NULL,'EPSG','7022','EPSG','8901','1950-06-30',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13571','geodetic_datum','EPSG','6230','EPSG','1296','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6231','European Datum 1987',NULL,'EPSG','7022','EPSG','8901','1987-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13572','geodetic_datum','EPSG','6231','EPSG','1297','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6232','Fahud',NULL,'EPSG','7012','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13573','geodetic_datum','EPSG','6232','EPSG','4009','EPSG','1216');
INSERT INTO "geodetic_datum" VALUES('EPSG','6233','Gandajika 1970',NULL,'EPSG','7022','EPSG','8901','1970-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13574','geodetic_datum','EPSG','6233','EPSG','1152','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6234','Garoua',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13575','geodetic_datum','EPSG','6234','EPSG','1060','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6235','Guyane Francaise',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13576','geodetic_datum','EPSG','6235','EPSG','1097','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6236','Hu Tzu Shan 1950',NULL,'EPSG','7022','EPSG','8901','1950-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13577','geodetic_datum','EPSG','6236','EPSG','3315','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6237','Hungarian Datum 1972',NULL,'EPSG','7036','EPSG','8901','1972-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13578','geodetic_datum','EPSG','6237','EPSG','1119','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6238','Indonesian Datum 1974',NULL,'EPSG','7021','EPSG','8901','1974-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13579','geodetic_datum','EPSG','6238','EPSG','4020','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6239','Indian 1954',NULL,'EPSG','7015','EPSG','8901','1954-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13580','geodetic_datum','EPSG','6239','EPSG','1304','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6240','Indian 1975',NULL,'EPSG','7015','EPSG','8901','1975-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13581','geodetic_datum','EPSG','6240','EPSG','3741','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6241','Jamaica 1875',NULL,'EPSG','7034','EPSG','8901','1875-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13582','geodetic_datum','EPSG','6241','EPSG','3342','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6242','Jamaica 1969',NULL,'EPSG','7008','EPSG','8901','1969-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13583','geodetic_datum','EPSG','6242','EPSG','3342','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6243','Kalianpur 1880',NULL,'EPSG','7042','EPSG','8901','1880-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13584','geodetic_datum','EPSG','6243','EPSG','1307','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6244','Kandawala',NULL,'EPSG','7015','EPSG','8901','1930-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13585','geodetic_datum','EPSG','6244','EPSG','3310','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6245','Kertau 1968',NULL,'EPSG','7018','EPSG','8901','1968-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13586','geodetic_datum','EPSG','6245','EPSG','4223','EPSG','1185');
INSERT INTO "geodetic_datum" VALUES('EPSG','6246','Kuwait Oil Company',NULL,'EPSG','7012','EPSG','8901','1952-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13587','geodetic_datum','EPSG','6246','EPSG','3267','EPSG','1216');
INSERT INTO "geodetic_datum" VALUES('EPSG','6247','La Canoa',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13588','geodetic_datum','EPSG','6247','EPSG','3327','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','6248','Provisional South American Datum 1956',NULL,'EPSG','7022','EPSG','8901','1956-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13589','geodetic_datum','EPSG','6248','EPSG','1348','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6249','Lake',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13590','geodetic_datum','EPSG','6249','EPSG','1312','EPSG','1216');
INSERT INTO "geodetic_datum" VALUES('EPSG','6250','Leigon',NULL,'EPSG','7012','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13591','geodetic_datum','EPSG','6250','EPSG','1104','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6251','Liberia 1964',NULL,'EPSG','7012','EPSG','8901','1964-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13592','geodetic_datum','EPSG','6251','EPSG','3270','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6252','Lome',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13593','geodetic_datum','EPSG','6252','EPSG','1232','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6253','Luzon 1911',NULL,'EPSG','7008','EPSG','8901','1911-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13594','geodetic_datum','EPSG','6253','EPSG','3969','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6254','Hito XVIII 1963',NULL,'EPSG','7022','EPSG','8901','1963-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13595','geodetic_datum','EPSG','6254','EPSG','1303','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6255','Herat North',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13596','geodetic_datum','EPSG','6255','EPSG','1024','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6256','Mahe 1971',NULL,'EPSG','7012','EPSG','8901','1971-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13597','geodetic_datum','EPSG','6256','EPSG','2369','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6257','Makassar',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13598','geodetic_datum','EPSG','6257','EPSG','1316','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6259','Malongo 1987',NULL,'EPSG','7022','EPSG','8901','1987-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13600','geodetic_datum','EPSG','6259','EPSG','3180','EPSG','1136');
INSERT INTO "geodetic_datum" VALUES('EPSG','6260','Manoca',NULL,'EPSG','7012','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13601','geodetic_datum','EPSG','6260','EPSG','1060','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6261','Merchich',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13602','geodetic_datum','EPSG','6261','EPSG','4581','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6262','Massawa',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13603','geodetic_datum','EPSG','6262','EPSG','1089','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6263','Minna',NULL,'EPSG','7012','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13604','geodetic_datum','EPSG','6263','EPSG','1178','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6264','Mhast',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13605','geodetic_datum','EPSG','6264','EPSG','1318','EPSG','1103');
INSERT INTO "geodetic_datum" VALUES('EPSG','6265','Monte Mario',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13606','geodetic_datum','EPSG','6265','EPSG','3343','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6266','M''poraloko',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13607','geodetic_datum','EPSG','6266','EPSG','1100','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6267','North American Datum 1927',NULL,'EPSG','7008','EPSG','8901','1927-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13608','geodetic_datum','EPSG','6267','EPSG','1349','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6268','NAD27 Michigan',NULL,'EPSG','7009','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13609','geodetic_datum','EPSG','6268','EPSG','1391','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6269','North American Datum 1983',NULL,'EPSG','7019','EPSG','8901','1986-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13610','geodetic_datum','EPSG','6269','EPSG','1350','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6270','Nahrwan 1967',NULL,'EPSG','7012','EPSG','8901','1967-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13611','geodetic_datum','EPSG','6270','EPSG','1351','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6271','Naparima 1972',NULL,'EPSG','7022','EPSG','8901','1972-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13612','geodetic_datum','EPSG','6271','EPSG','1322','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6272','New Zealand Geodetic Datum 1949',NULL,'EPSG','7022','EPSG','8901','1949-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13613','geodetic_datum','EPSG','6272','EPSG','3285','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6273','NGO 1948',NULL,'EPSG','7005','EPSG','8901','1948-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13614','geodetic_datum','EPSG','6273','EPSG','1352','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6274','Datum 73',NULL,'EPSG','7022','EPSG','8901','1974-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13615','geodetic_datum','EPSG','6274','EPSG','1294','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6275','Nouvelle Triangulation Francaise',NULL,'EPSG','7011','EPSG','8901','1895-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13616','geodetic_datum','EPSG','6275','EPSG','3694','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6276','NSWC 9Z-2',NULL,'EPSG','7025','EPSG','8901','1976-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13617','geodetic_datum','EPSG','6276','EPSG','1262','EPSG','1245');
INSERT INTO "geodetic_datum" VALUES('EPSG','6277','Ordnance Survey of Great Britain 1936',NULL,'EPSG','7001','EPSG','8901','1936-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13618','geodetic_datum','EPSG','6277','EPSG','4390','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6278','OSGB 1970 (SN)',NULL,'EPSG','7001','EPSG','8901','1970-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13619','geodetic_datum','EPSG','6278','EPSG','1264','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6279','OS (SN) 1980',NULL,'EPSG','7001','EPSG','8901','1980-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13620','geodetic_datum','EPSG','6279','EPSG','1354','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6280','Padang 1884',NULL,'EPSG','7004','EPSG','8901','1884-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13621','geodetic_datum','EPSG','6280','EPSG','1355','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6281','Palestine 1923',NULL,'EPSG','7010','EPSG','8901','1923-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13622','geodetic_datum','EPSG','6281','EPSG','1356','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6282','Congo 1960 Pointe Noire',NULL,'EPSG','7011','EPSG','8901','1960-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13623','geodetic_datum','EPSG','6282','EPSG','1072','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6283','Geocentric Datum of Australia 1994',NULL,'EPSG','7019','EPSG','8901','1994-01-14',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13624','geodetic_datum','EPSG','6283','EPSG','4177','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6284','Pulkovo 1942',NULL,'EPSG','7024','EPSG','8901','1942-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13625','geodetic_datum','EPSG','6284','EPSG','2423','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6285','Qatar 1974',NULL,'EPSG','7022','EPSG','8901','1974-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13626','geodetic_datum','EPSG','6285','EPSG','1195','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6286','Qatar 1948',NULL,'EPSG','7020','EPSG','8901','1948-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13627','geodetic_datum','EPSG','6286','EPSG','1346','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6287','Qornoq',NULL,'EPSG','7022','EPSG','8901','1927-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13628','geodetic_datum','EPSG','6287','EPSG','1107','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6288','Loma Quintana',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13629','geodetic_datum','EPSG','6288','EPSG','1313','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6289','Amersfoort',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13630','geodetic_datum','EPSG','6289','EPSG','1275','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6291','South American Datum 1969',NULL,'EPSG','7036','EPSG','8901','1969-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13631','geodetic_datum','EPSG','6291','EPSG','1358','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6292','Sapper Hill 1943',NULL,'EPSG','7022','EPSG','8901','1943-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13632','geodetic_datum','EPSG','6292','EPSG','3247','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6293','Schwarzeck',NULL,'EPSG','7046','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13633','geodetic_datum','EPSG','6293','EPSG','1169','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6294','Segora',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13634','geodetic_datum','EPSG','6294','EPSG','1359','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6295','Serindung',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13635','geodetic_datum','EPSG','6295','EPSG','4005','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6296','Sudan',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13636','geodetic_datum','EPSG','6296','EPSG','1361','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6297','Tananarive 1925',NULL,'EPSG','7022','EPSG','8901','1925-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13637','geodetic_datum','EPSG','6297','EPSG','1149','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6298','Timbalai 1948',NULL,'EPSG','7016','EPSG','8901','1948-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13638','geodetic_datum','EPSG','6298','EPSG','1362','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6299','TM65',NULL,'EPSG','7002','EPSG','8901','1965-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13639','geodetic_datum','EPSG','6299','EPSG','1305','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6300','Geodetic Datum of 1965',NULL,'EPSG','7002','EPSG','8901','1975-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13640','geodetic_datum','EPSG','6300','EPSG','1305','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','6301','Tokyo',NULL,'EPSG','7004','EPSG','8901','1918-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13641','geodetic_datum','EPSG','6301','EPSG','1364','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6302','Trinidad 1903',NULL,'EPSG','7007','EPSG','8901','1903-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13642','geodetic_datum','EPSG','6302','EPSG','1339','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6303','Trucial Coast 1948',NULL,'EPSG','7020','EPSG','8901','1948-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13643','geodetic_datum','EPSG','6303','EPSG','1363','EPSG','1216');
INSERT INTO "geodetic_datum" VALUES('EPSG','6304','Voirol 1875',NULL,'EPSG','7011','EPSG','8901','1875-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13644','geodetic_datum','EPSG','6304','EPSG','1365','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6306','Bern 1938',NULL,'EPSG','7004','EPSG','8901','1938-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13645','geodetic_datum','EPSG','6306','EPSG','1286','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6307','Nord Sahara 1959',NULL,'EPSG','7012','EPSG','8901','1959-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13646','geodetic_datum','EPSG','6307','EPSG','1026','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6308','Stockholm 1938',NULL,'EPSG','7004','EPSG','8901','1938-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13647','geodetic_datum','EPSG','6308','EPSG','3313','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6309','Yacare',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13648','geodetic_datum','EPSG','6309','EPSG','3326','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6310','Yoff',NULL,'EPSG','7011','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13649','geodetic_datum','EPSG','6310','EPSG','1207','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6311','Zanderij',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13650','geodetic_datum','EPSG','6311','EPSG','1222','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6312','Militar-Geographische Institut',NULL,'EPSG','7004','EPSG','8901','1901-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13651','geodetic_datum','EPSG','6312','EPSG','1037','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6313','Reseau National Belge 1972',NULL,'EPSG','7022','EPSG','8901','1972-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13652','geodetic_datum','EPSG','6313','EPSG','1347','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6314','Deutsches Hauptdreiecksnetz',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13653','geodetic_datum','EPSG','6314','EPSG','2326','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6315','Conakry 1905',NULL,'EPSG','7011','EPSG','8901','1905-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13654','geodetic_datum','EPSG','6315','EPSG','3257','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6316','Dealul Piscului 1930',NULL,'EPSG','7022','EPSG','8901','1930-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13655','geodetic_datum','EPSG','6316','EPSG','3295','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6317','Dealul Piscului 1970',NULL,'EPSG','7024','EPSG','8901','1970-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13656','geodetic_datum','EPSG','6317','EPSG','1197','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6318','National Geodetic Network',NULL,'EPSG','7030','EPSG','8901','1993-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13657','geodetic_datum','EPSG','6318','EPSG','3267','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6319','Kuwait Utility',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13658','geodetic_datum','EPSG','6319','EPSG','1310','EPSG','1054');
INSERT INTO "geodetic_datum" VALUES('EPSG','6322','World Geodetic System 1972',NULL,'EPSG','7043','EPSG','8901','1972-01-01',1972.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13659','geodetic_datum','EPSG','6322','EPSG','1262','EPSG','1245');
INSERT INTO "geodetic_datum" VALUES('EPSG','6324','WGS 72 Transit Broadcast Ephemeris',NULL,'EPSG','7043','EPSG','8901','1972-01-01',1972.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13660','geodetic_datum','EPSG','6324','EPSG','1262','EPSG','1245');
INSERT INTO "geodetic_datum" VALUES('EPSG','6600','Anguilla 1957',NULL,'EPSG','7012','EPSG','8901','1957-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13662','geodetic_datum','EPSG','6600','EPSG','3214','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6601','Antigua 1943',NULL,'EPSG','7012','EPSG','8901','1943-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13663','geodetic_datum','EPSG','6601','EPSG','1273','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6602','Dominica 1945',NULL,'EPSG','7012','EPSG','8901','1945-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13664','geodetic_datum','EPSG','6602','EPSG','3239','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6603','Grenada 1953',NULL,'EPSG','7012','EPSG','8901','1953-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13665','geodetic_datum','EPSG','6603','EPSG','1551','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6604','Montserrat 1958',NULL,'EPSG','7012','EPSG','8901','1958-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13666','geodetic_datum','EPSG','6604','EPSG','3279','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6605','St. Kitts 1955',NULL,'EPSG','7012','EPSG','8901','1955-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13667','geodetic_datum','EPSG','6605','EPSG','3297','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6606','St. Lucia 1955',NULL,'EPSG','7012','EPSG','8901','1955-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13668','geodetic_datum','EPSG','6606','EPSG','3298','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6607','St. Vincent 1945',NULL,'EPSG','7012','EPSG','8901','1945-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13669','geodetic_datum','EPSG','6607','EPSG','3300','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6608','North American Datum 1927 (1976)',NULL,'EPSG','7008','EPSG','8901','1975-05-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13670','geodetic_datum','EPSG','6608','EPSG','1367','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6609','North American Datum 1927 (CGQ77)',NULL,'EPSG','7008','EPSG','8901','1977-05-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13671','geodetic_datum','EPSG','6609','EPSG','1368','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6610','Xian 1980',NULL,'EPSG','7049','EPSG','8901','1980-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13672','geodetic_datum','EPSG','6610','EPSG','3228','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','6611','Hong Kong 1980',NULL,'EPSG','7022','EPSG','8901','1980-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13673','geodetic_datum','EPSG','6611','EPSG','1118','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6612','Japanese Geodetic Datum 2000',NULL,'EPSG','7019','EPSG','8901','2002-04-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13674','geodetic_datum','EPSG','6612','EPSG','1129','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','6613','Gunung Segara',NULL,'EPSG','7004','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13675','geodetic_datum','EPSG','6613','EPSG','1360','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6614','Qatar National Datum 1995',NULL,'EPSG','7022','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13676','geodetic_datum','EPSG','6614','EPSG','1346','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6615','Porto Santo 1936',NULL,'EPSG','7022','EPSG','8901','1936-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13677','geodetic_datum','EPSG','6615','EPSG','1314','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6616','Selvagem Grande',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13678','geodetic_datum','EPSG','6616','EPSG','2779','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6618','South American Datum 1969',NULL,'EPSG','7050','EPSG','8901','1969-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13679','geodetic_datum','EPSG','6618','EPSG','1358','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6619','SWEREF99',NULL,'EPSG','7019','EPSG','8901','1999-06-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13680','geodetic_datum','EPSG','6619','EPSG','1225','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6620','Point 58',NULL,'EPSG','7012','EPSG','8901','1969-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13681','geodetic_datum','EPSG','6620','EPSG','2790','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6621','Fort Marigot',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13682','geodetic_datum','EPSG','6621','EPSG','2828','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6622','Guadeloupe 1948',NULL,'EPSG','7022','EPSG','8901','1948-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13683','geodetic_datum','EPSG','6622','EPSG','2829','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6623','Centre Spatial Guyanais 1967',NULL,'EPSG','7022','EPSG','8901','1967-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13684','geodetic_datum','EPSG','6623','EPSG','3105','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6624','Reseau Geodesique Francais Guyane 1995',NULL,'EPSG','7019','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13685','geodetic_datum','EPSG','6624','EPSG','1097','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6625','Martinique 1938',NULL,'EPSG','7022','EPSG','8901','1938-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13686','geodetic_datum','EPSG','6625','EPSG','3276','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6626','Reunion 1947',NULL,'EPSG','7022','EPSG','8901','1947-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13687','geodetic_datum','EPSG','6626','EPSG','3337','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6627','Reseau Geodesique de la Reunion 1992',NULL,'EPSG','7019','EPSG','8901','1992-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13688','geodetic_datum','EPSG','6627','EPSG','3902','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6628','Tahiti 52',NULL,'EPSG','7022','EPSG','8901','1952-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13689','geodetic_datum','EPSG','6628','EPSG','2811','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6629','Tahaa 54',NULL,'EPSG','7022','EPSG','8901','1954-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13690','geodetic_datum','EPSG','6629','EPSG','2812','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6630','IGN72 Nuku Hiva',NULL,'EPSG','7022','EPSG','8901','1972-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13691','geodetic_datum','EPSG','6630','EPSG','3129','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6631','K0 1949',NULL,'EPSG','7022','EPSG','8901','1949-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13692','geodetic_datum','EPSG','6631','EPSG','2816','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6632','Combani 1950',NULL,'EPSG','7022','EPSG','8901','1950-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13693','geodetic_datum','EPSG','6632','EPSG','3340','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6633','IGN56 Lifou',NULL,'EPSG','7022','EPSG','8901','1956-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13694','geodetic_datum','EPSG','6633','EPSG','2814','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6634','IGN72 Grande Terre',NULL,'EPSG','7022','EPSG','8901','1972-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13695','geodetic_datum','EPSG','6634','EPSG','2822','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6635','ST87 Ouvea',NULL,'EPSG','7022','EPSG','8901','1987-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13696','geodetic_datum','EPSG','6635','EPSG','2813','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6636','Petrels 1972',NULL,'EPSG','7022','EPSG','8901','1972-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13697','geodetic_datum','EPSG','6636','EPSG','2817','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6637','Pointe Geologie Perroud 1950',NULL,'EPSG','7022','EPSG','8901','1950-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13698','geodetic_datum','EPSG','6637','EPSG','2818','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6638','Saint Pierre et Miquelon 1950',NULL,'EPSG','7008','EPSG','8901','1950-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13699','geodetic_datum','EPSG','6638','EPSG','3299','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6639','MOP78',NULL,'EPSG','7022','EPSG','8901','1978-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13700','geodetic_datum','EPSG','6639','EPSG','2815','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6640','Reseau de Reference des Antilles Francaises 1991',NULL,'EPSG','7030','EPSG','8901','1991-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13701','geodetic_datum','EPSG','6640','EPSG','2824','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6641','IGN53 Mare',NULL,'EPSG','7022','EPSG','8901','1953-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13702','geodetic_datum','EPSG','6641','EPSG','2819','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6642','ST84 Ile des Pins',NULL,'EPSG','7022','EPSG','8901','1984-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13703','geodetic_datum','EPSG','6642','EPSG','2820','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6643','ST71 Belep',NULL,'EPSG','7022','EPSG','8901','1971-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13704','geodetic_datum','EPSG','6643','EPSG','2821','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6644','NEA74 Noumea',NULL,'EPSG','7022','EPSG','8901','1974-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13705','geodetic_datum','EPSG','6644','EPSG','2823','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6645','Reseau Geodesique Nouvelle Caledonie 1991',NULL,'EPSG','7022','EPSG','8901','1991-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13706','geodetic_datum','EPSG','6645','EPSG','1174','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6646','Grand Comoros',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13707','geodetic_datum','EPSG','6646','EPSG','2807','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6647','International Terrestrial Reference Frame 1988',NULL,'EPSG','7019','EPSG','8901','1988-01-01',1988.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13708','geodetic_datum','EPSG','6647','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6648','International Terrestrial Reference Frame 1989',NULL,'EPSG','7019','EPSG','8901','1988-01-01',1988.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13709','geodetic_datum','EPSG','6648','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6649','International Terrestrial Reference Frame 1990',NULL,'EPSG','7019','EPSG','8901','1988-01-01',1988.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13710','geodetic_datum','EPSG','6649','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6650','International Terrestrial Reference Frame 1991',NULL,'EPSG','7019','EPSG','8901','1988-01-01',1988.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13711','geodetic_datum','EPSG','6650','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6651','International Terrestrial Reference Frame 1992',NULL,'EPSG','7019','EPSG','8901','1988-01-01',1988.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13712','geodetic_datum','EPSG','6651','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6652','International Terrestrial Reference Frame 1993',NULL,'EPSG','7019','EPSG','8901','1993-01-01',1993.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13713','geodetic_datum','EPSG','6652','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6653','International Terrestrial Reference Frame 1994',NULL,'EPSG','7019','EPSG','8901','1993-01-01',1993.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13714','geodetic_datum','EPSG','6653','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6654','International Terrestrial Reference Frame 1996',NULL,'EPSG','7019','EPSG','8901','1997-01-01',1997.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13715','geodetic_datum','EPSG','6654','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6655','International Terrestrial Reference Frame 1997',NULL,'EPSG','7019','EPSG','8901','1997-01-01',1997.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13716','geodetic_datum','EPSG','6655','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6656','International Terrestrial Reference Frame 2000',NULL,'EPSG','7019','EPSG','8901','1997-01-01',1997.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13717','geodetic_datum','EPSG','6656','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6657','Reykjavik 1900',NULL,'EPSG','7051','EPSG','8901','1900-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13718','geodetic_datum','EPSG','6657','EPSG','3262','EPSG','1211');
INSERT INTO "geodetic_datum" VALUES('EPSG','6658','Hjorsey 1955',NULL,'EPSG','7022','EPSG','8901','1955-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13719','geodetic_datum','EPSG','6658','EPSG','3262','EPSG','1062');
INSERT INTO "geodetic_datum" VALUES('EPSG','6659','Islands Net 1993',NULL,'EPSG','7019','EPSG','8901','1993-08-07',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13720','geodetic_datum','EPSG','6659','EPSG','1120','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6660','Helle 1954',NULL,'EPSG','7022','EPSG','8901','1954-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13721','geodetic_datum','EPSG','6660','EPSG','2869','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6661','Latvian geodetic coordinate system 1992',NULL,'EPSG','7019','EPSG','8901','1992-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13722','geodetic_datum','EPSG','6661','EPSG','1139','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6663','Porto Santo 1995',NULL,'EPSG','7022','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13723','geodetic_datum','EPSG','6663','EPSG','1314','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6664','Azores Oriental Islands 1995',NULL,'EPSG','7022','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13724','geodetic_datum','EPSG','6664','EPSG','1345','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6665','Azores Central Islands 1995',NULL,'EPSG','7022','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13725','geodetic_datum','EPSG','6665','EPSG','1301','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6666','Lisbon 1890',NULL,'EPSG','7004','EPSG','8901','1937-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13726','geodetic_datum','EPSG','6666','EPSG','1294','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6667','Iraq-Kuwait Boundary Datum 1992',NULL,'EPSG','7030','EPSG','8901','1992-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13727','geodetic_datum','EPSG','6667','EPSG','2876','EPSG','1053');
INSERT INTO "geodetic_datum" VALUES('EPSG','6668','European Datum 1979',NULL,'EPSG','7022','EPSG','8901','1979-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13728','geodetic_datum','EPSG','6668','EPSG','1297','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6670','Istituto Geografico Militaire 1995',NULL,'EPSG','7019','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','14401','geodetic_datum','EPSG','6670','EPSG','3343','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6671','Voirol 1879',NULL,'EPSG','7011','EPSG','8901','1879-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13730','geodetic_datum','EPSG','6671','EPSG','1365','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6672','Chatham Islands Datum 1971',NULL,'EPSG','7022','EPSG','8901','1971-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13731','geodetic_datum','EPSG','6672','EPSG','2889','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','6673','Chatham Islands Datum 1979',NULL,'EPSG','7022','EPSG','8901','1979-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13732','geodetic_datum','EPSG','6673','EPSG','2889','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','6674','Sistema de Referencia Geocentrico para las AmericaS 2000',NULL,'EPSG','7019','EPSG','8901','2000-05-26',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13733','geodetic_datum','EPSG','6674','EPSG','3418','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6675','Guam 1963',NULL,'EPSG','7008','EPSG','8901','1963-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13734','geodetic_datum','EPSG','6675','EPSG','4525','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6676','Vientiane 1982',NULL,'EPSG','7024','EPSG','8901','1982-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13735','geodetic_datum','EPSG','6676','EPSG','1138','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6677','Lao 1993',NULL,'EPSG','7024','EPSG','8901','1993-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13736','geodetic_datum','EPSG','6677','EPSG','1138','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6678','Lao National Datum 1997',NULL,'EPSG','7024','EPSG','8901','1997-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13737','geodetic_datum','EPSG','6678','EPSG','1138','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','6679','Jouik 1961',NULL,'EPSG','7012','EPSG','8901','1961-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13738','geodetic_datum','EPSG','6679','EPSG','2967','EPSG','1198');
INSERT INTO "geodetic_datum" VALUES('EPSG','6680','Nouakchott 1965',NULL,'EPSG','7012','EPSG','8901','1965-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13739','geodetic_datum','EPSG','6680','EPSG','2968','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6681','Mauritania 1999',NULL,'EPSG','7012','EPSG','8901','1999-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13740','geodetic_datum','EPSG','6681','EPSG','1157','EPSG','1249');
INSERT INTO "geodetic_datum" VALUES('EPSG','6682','Gulshan 303',NULL,'EPSG','7015','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13741','geodetic_datum','EPSG','6682','EPSG','1041','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6683','Philippine Reference System 1992',NULL,'EPSG','7008','EPSG','8901','1992-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13742','geodetic_datum','EPSG','6683','EPSG','1190','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6684','Gan 1970',NULL,'EPSG','7022','EPSG','8901','1970-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13743','geodetic_datum','EPSG','6684','EPSG','3274','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6685','Gandajika',NULL,'EPSG','7022','EPSG','8901','1953-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13744','geodetic_datum','EPSG','6685','EPSG','1259','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6686','Marco Geocentrico Nacional de Referencia',NULL,'EPSG','7019','EPSG','8901','2004-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13745','geodetic_datum','EPSG','6686','EPSG','1070','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6687','Reseau Geodesique de la Polynesie Francaise',NULL,'EPSG','7019','EPSG','8901','1993-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13746','geodetic_datum','EPSG','6687','EPSG','1098','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6688','Fatu Iva 72',NULL,'EPSG','7022','EPSG','8901','1972-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13747','geodetic_datum','EPSG','6688','EPSG','3133','EPSG','1201');
INSERT INTO "geodetic_datum" VALUES('EPSG','6689','IGN63 Hiva Oa',NULL,'EPSG','7022','EPSG','8901','1963-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13748','geodetic_datum','EPSG','6689','EPSG','3130','EPSG','1201');
INSERT INTO "geodetic_datum" VALUES('EPSG','6690','Tahiti 79',NULL,'EPSG','7022','EPSG','8901','1979-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13749','geodetic_datum','EPSG','6690','EPSG','3124','EPSG','1201');
INSERT INTO "geodetic_datum" VALUES('EPSG','6691','Moorea 87',NULL,'EPSG','7022','EPSG','8901','1987-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13750','geodetic_datum','EPSG','6691','EPSG','3125','EPSG','1201');
INSERT INTO "geodetic_datum" VALUES('EPSG','6692','Maupiti 83',NULL,'EPSG','7022','EPSG','8901','1983-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13751','geodetic_datum','EPSG','6692','EPSG','3126','EPSG','1201');
INSERT INTO "geodetic_datum" VALUES('EPSG','6693','Nakhl-e Ghanem',NULL,'EPSG','7030','EPSG','8901','2005-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13752','geodetic_datum','EPSG','6693','EPSG','2362','EPSG','1140');
INSERT INTO "geodetic_datum" VALUES('EPSG','6694','Posiciones Geodesicas Argentinas 1994',NULL,'EPSG','7030','EPSG','8901','1994-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','18565','geodetic_datum','EPSG','6694','EPSG','1033','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6695','Katanga 1955',NULL,'EPSG','7008','EPSG','8901','1955-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13754','geodetic_datum','EPSG','6695','EPSG','3147','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','6696','Kasai 1953',NULL,'EPSG','7012','EPSG','8901','1953-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13755','geodetic_datum','EPSG','6696','EPSG','3148','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','6697','IGC 1962 Arc of the 6th Parallel South',NULL,'EPSG','7012','EPSG','8901','1962-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13756','geodetic_datum','EPSG','6697','EPSG','3149','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6698','IGN 1962 Kerguelen',NULL,'EPSG','7022','EPSG','8901','1962-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13757','geodetic_datum','EPSG','6698','EPSG','2816','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6699','Le Pouce 1934',NULL,'EPSG','7012','EPSG','8901','1934-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13758','geodetic_datum','EPSG','6699','EPSG','3209','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6700','IGN Astro 1960',NULL,'EPSG','7012','EPSG','8901','1960-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13759','geodetic_datum','EPSG','6700','EPSG','3277','EPSG','1241');
INSERT INTO "geodetic_datum" VALUES('EPSG','6701','Institut Geographique du Congo Belge 1955',NULL,'EPSG','7012','EPSG','8901','1955-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13760','geodetic_datum','EPSG','6701','EPSG','3171','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','6702','Mauritania 1999',NULL,'EPSG','7019','EPSG','8901','1999-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13761','geodetic_datum','EPSG','6702','EPSG','1157','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6703','Missao Hidrografico Angola y Sao Tome 1951',NULL,'EPSG','7012','EPSG','8901','1951-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13762','geodetic_datum','EPSG','6703','EPSG','1318','EPSG','1103');
INSERT INTO "geodetic_datum" VALUES('EPSG','6704','Mhast (onshore)',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13763','geodetic_datum','EPSG','6704','EPSG','3179','EPSG','1136');
INSERT INTO "geodetic_datum" VALUES('EPSG','6705','Mhast (offshore)',NULL,'EPSG','7022','EPSG','8901','1979-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13764','geodetic_datum','EPSG','6705','EPSG','3180','EPSG','1136');
INSERT INTO "geodetic_datum" VALUES('EPSG','6706','Egypt Gulf of Suez S-650 TL',NULL,'EPSG','7020','EPSG','8901','1980-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13765','geodetic_datum','EPSG','6706','EPSG','2341','EPSG','1136');
INSERT INTO "geodetic_datum" VALUES('EPSG','6707','Tern Island 1961',NULL,'EPSG','7022','EPSG','8901','1961-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13766','geodetic_datum','EPSG','6707','EPSG','3181','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6708','Cocos Islands 1965',NULL,'EPSG','7003','EPSG','8901','1965-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13767','geodetic_datum','EPSG','6708','EPSG','1069','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6709','Iwo Jima 1945',NULL,'EPSG','7022','EPSG','8901','1945-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13768','geodetic_datum','EPSG','6709','EPSG','3200','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6710','Astro DOS 71',NULL,'EPSG','7022','EPSG','8901','1971-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13769','geodetic_datum','EPSG','6710','EPSG','3183','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6711','Marcus Island 1952',NULL,'EPSG','7022','EPSG','8901','1952-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13770','geodetic_datum','EPSG','6711','EPSG','1872','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6712','Ascension Island 1958',NULL,'EPSG','7022','EPSG','8901','1958-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13771','geodetic_datum','EPSG','6712','EPSG','3182','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6713','Ayabelle Lighthouse',NULL,'EPSG','7012','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13772','geodetic_datum','EPSG','6713','EPSG','1081','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6714','Bellevue',NULL,'EPSG','7022','EPSG','8901','1960-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13773','geodetic_datum','EPSG','6714','EPSG','3193','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6715','Camp Area Astro',NULL,'EPSG','7022','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13774','geodetic_datum','EPSG','6715','EPSG','3205','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6716','Phoenix Islands 1966',NULL,'EPSG','7022','EPSG','8901','1966-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13775','geodetic_datum','EPSG','6716','EPSG','3196','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6717','Cape Canaveral',NULL,'EPSG','7008','EPSG','8901','1963-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13776','geodetic_datum','EPSG','6717','EPSG','3206','EPSG','1233');
INSERT INTO "geodetic_datum" VALUES('EPSG','6718','Solomon 1968',NULL,'EPSG','7022','EPSG','8901','1968-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13777','geodetic_datum','EPSG','6718','EPSG','1213','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6719','Easter Island 1967',NULL,'EPSG','7022','EPSG','8901','1967-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13778','geodetic_datum','EPSG','6719','EPSG','3188','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6720','Fiji Geodetic Datum 1986',NULL,'EPSG','7043','EPSG','8901','1986-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13779','geodetic_datum','EPSG','6720','EPSG','1094','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6721','Fiji 1956',NULL,'EPSG','7022','EPSG','8901','1956-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13780','geodetic_datum','EPSG','6721','EPSG','3398','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6722','South Georgia 1968',NULL,'EPSG','7022','EPSG','8901','1968-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13781','geodetic_datum','EPSG','6722','EPSG','3529','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6723','Grand Cayman Geodetic Datum 1959',NULL,'EPSG','7008','EPSG','8901','1959-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13782','geodetic_datum','EPSG','6723','EPSG','3185','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6724','Diego Garcia 1969',NULL,'EPSG','7022','EPSG','8901','1969-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13783','geodetic_datum','EPSG','6724','EPSG','3189','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6725','Johnston Island 1961',NULL,'EPSG','7022','EPSG','8901','1961-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13784','geodetic_datum','EPSG','6725','EPSG','3201','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6726','Sister Islands Geodetic Datum 1961',NULL,'EPSG','7008','EPSG','8901','1961-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13785','geodetic_datum','EPSG','6726','EPSG','3186','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6727','Midway 1961',NULL,'EPSG','7022','EPSG','8901','1961-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13786','geodetic_datum','EPSG','6727','EPSG','3202','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6728','Pico de las Nieves 1984',NULL,'EPSG','7022','EPSG','8901','1984-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13787','geodetic_datum','EPSG','6728','EPSG','4598','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6729','Pitcairn 1967',NULL,'EPSG','7022','EPSG','8901','1967-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13788','geodetic_datum','EPSG','6729','EPSG','3208','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6730','Santo 1965',NULL,'EPSG','7022','EPSG','8901','1965-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13789','geodetic_datum','EPSG','6730','EPSG','3194','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6731','Viti Levu 1916',NULL,'EPSG','7012','EPSG','8901','1916-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13790','geodetic_datum','EPSG','6731','EPSG','3195','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6732','Marshall Islands 1960',NULL,'EPSG','7053','EPSG','8901','1960-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13791','geodetic_datum','EPSG','6732','EPSG','3191','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6733','Wake Island 1952',NULL,'EPSG','7022','EPSG','8901','1952-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13792','geodetic_datum','EPSG','6733','EPSG','3190','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6734','Tristan 1968',NULL,'EPSG','7022','EPSG','8901','1968-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13793','geodetic_datum','EPSG','6734','EPSG','3184','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6735','Kusaie 1951',NULL,'EPSG','7022','EPSG','8901','1951-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13794','geodetic_datum','EPSG','6735','EPSG','3192','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6736','Deception Island',NULL,'EPSG','7012','EPSG','8901',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13795','geodetic_datum','EPSG','6736','EPSG','3204','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6737','Korean Geodetic Datum 2002',NULL,'EPSG','7019','EPSG','8901','2002-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13796','geodetic_datum','EPSG','6737','EPSG','1135','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6738','Hong Kong 1963',NULL,'EPSG','7007','EPSG','8901','1963-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13797','geodetic_datum','EPSG','6738','EPSG','1118','EPSG','1201');
INSERT INTO "geodetic_datum" VALUES('EPSG','6739','Hong Kong 1963(67)',NULL,'EPSG','7022','EPSG','8901','1967-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13798','geodetic_datum','EPSG','6739','EPSG','1118','EPSG','1160');
INSERT INTO "geodetic_datum" VALUES('EPSG','6740','Parametry Zemli 1990',NULL,'EPSG','7054','EPSG','8901','1990-01-01',1990.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13799','geodetic_datum','EPSG','6740','EPSG','1262','EPSG','1177');
INSERT INTO "geodetic_datum" VALUES('EPSG','6741','Faroe Datum 1954',NULL,'EPSG','7022','EPSG','8901','1954-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13800','geodetic_datum','EPSG','6741','EPSG','3248','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6742','Geodetic Datum of Malaysia 2000',NULL,'EPSG','7019','EPSG','8901','2003-08-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13801','geodetic_datum','EPSG','6742','EPSG','1151','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6743','Karbala 1979',NULL,'EPSG','7012','EPSG','8901','1979-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13802','geodetic_datum','EPSG','6743','EPSG','3625','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6744','Nahrwan 1934',NULL,'EPSG','7012','EPSG','8901','1934-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13803','geodetic_datum','EPSG','6744','EPSG','4238','EPSG','1136');
INSERT INTO "geodetic_datum" VALUES('EPSG','6745','Rauenberg Datum/83',NULL,'EPSG','7004','EPSG','8901','1983-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13804','geodetic_datum','EPSG','6745','EPSG','2545','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6746','Potsdam Datum/83',NULL,'EPSG','7004','EPSG','8901','1983-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13805','geodetic_datum','EPSG','6746','EPSG','2544','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6747','Greenland 1996',NULL,'EPSG','7019','EPSG','8901','1996-08-14',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13806','geodetic_datum','EPSG','6747','EPSG','1107','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6748','Vanua Levu 1915',NULL,'EPSG','7055','EPSG','8901','1915-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13807','geodetic_datum','EPSG','6748','EPSG','3401','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6749','Reseau Geodesique de Nouvelle Caledonie 91-93',NULL,'EPSG','7019','EPSG','8901','1989-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13808','geodetic_datum','EPSG','6749','EPSG','1174','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6750','ST87 Ouvea',NULL,'EPSG','7030','EPSG','8901','1987-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13809','geodetic_datum','EPSG','6750','EPSG','2813','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6751','Kertau (RSO)',NULL,'EPSG','7056','EPSG','8901','1969-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13810','geodetic_datum','EPSG','6751','EPSG','1309','EPSG','1250');
INSERT INTO "geodetic_datum" VALUES('EPSG','6752','Viti Levu 1912',NULL,'EPSG','7055','EPSG','8901','1912-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13811','geodetic_datum','EPSG','6752','EPSG','3195','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6753','fk89',NULL,'EPSG','7022','EPSG','8901','1989-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13812','geodetic_datum','EPSG','6753','EPSG','3248','EPSG','1028');
INSERT INTO "geodetic_datum" VALUES('EPSG','6754','Libyan Geodetic Datum 2006',NULL,'EPSG','7022','EPSG','8901','2006-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13813','geodetic_datum','EPSG','6754','EPSG','1143','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','6755','Datum Geodesi Nasional 1995',NULL,'EPSG','7030','EPSG','8901','1995-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13814','geodetic_datum','EPSG','6755','EPSG','1122','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','6756','Vietnam 2000',NULL,'EPSG','7030','EPSG','8901','2000-07-12',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13815','geodetic_datum','EPSG','6756','EPSG','3328','EPSG','1178');
INSERT INTO "geodetic_datum" VALUES('EPSG','6757','SVY21',NULL,'EPSG','7030','EPSG','8901','2004-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13816','geodetic_datum','EPSG','6757','EPSG','1210','EPSG','1028');
INSERT INTO "geodetic_datum" VALUES('EPSG','6758','Jamaica 2001',NULL,'EPSG','7030','EPSG','8901','2001-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13817','geodetic_datum','EPSG','6758','EPSG','1128','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6759','NAD83 (National Spatial Reference System 2007)',NULL,'EPSG','7019','EPSG','8901','2007-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13818','geodetic_datum','EPSG','6759','EPSG','1511','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6760','World Geodetic System 1966',NULL,'EPSG','7025','EPSG','8901','1966-01-01',1966.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13819','geodetic_datum','EPSG','6760','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6761','Croatian Terrestrial Reference System',NULL,'EPSG','7019','EPSG','8901','1995-07-20',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13820','geodetic_datum','EPSG','6761','EPSG','1076','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6762','Bermuda 2000',NULL,'EPSG','7030','EPSG','8901','2000-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13821','geodetic_datum','EPSG','6762','EPSG','1047','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','6763','Pitcairn 2006',NULL,'EPSG','7030','EPSG','8901','2006-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13822','geodetic_datum','EPSG','6763','EPSG','3208','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','6764','Ross Sea Region Geodetic Datum 2000',NULL,'EPSG','7019','EPSG','8901','2000-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13823','geodetic_datum','EPSG','6764','EPSG','3558','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6765','Slovenia Geodetic Datum 1996',NULL,'EPSG','7019','EPSG','8901','1996-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13824','geodetic_datum','EPSG','6765','EPSG','1212','EPSG','1180');
INSERT INTO "geodetic_datum" VALUES('EPSG','6801','CH1903 (Bern)',NULL,'EPSG','7004','EPSG','8907','1903-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13825','geodetic_datum','EPSG','6801','EPSG','1286','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6802','Bogota 1975 (Bogota)',NULL,'EPSG','7022','EPSG','8904','1975-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13826','geodetic_datum','EPSG','6802','EPSG','3229','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6803','Lisbon 1937 (Lisbon)',NULL,'EPSG','7022','EPSG','8902','1937-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13827','geodetic_datum','EPSG','6803','EPSG','1294','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6804','Makassar (Jakarta)',NULL,'EPSG','7004','EPSG','8908',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13828','geodetic_datum','EPSG','6804','EPSG','1316','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6805','Militar-Geographische Institut (Ferro)',NULL,'EPSG','7004','EPSG','8909','1901-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13829','geodetic_datum','EPSG','6805','EPSG','1321','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6806','Monte Mario (Rome)',NULL,'EPSG','7022','EPSG','8906',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13830','geodetic_datum','EPSG','6806','EPSG','3343','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6807','Nouvelle Triangulation Francaise (Paris)',NULL,'EPSG','7011','EPSG','8903','1895-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13831','geodetic_datum','EPSG','6807','EPSG','3694','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6808','Padang 1884 (Jakarta)',NULL,'EPSG','7004','EPSG','8908','1884-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13832','geodetic_datum','EPSG','6808','EPSG','1355','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6809','Reseau National Belge 1950 (Brussels)',NULL,'EPSG','7022','EPSG','8910','1950-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13833','geodetic_datum','EPSG','6809','EPSG','1347','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6810','Tananarive 1925 (Paris)',NULL,'EPSG','7022','EPSG','8903','1925-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13834','geodetic_datum','EPSG','6810','EPSG','3273','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6811','Voirol 1875 (Paris)',NULL,'EPSG','7011','EPSG','8903','1875-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13835','geodetic_datum','EPSG','6811','EPSG','1365','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6813','Batavia (Jakarta)',NULL,'EPSG','7004','EPSG','8908',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13836','geodetic_datum','EPSG','6813','EPSG','1285','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6814','Stockholm 1938 (Stockholm)',NULL,'EPSG','7004','EPSG','8911','1938-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13837','geodetic_datum','EPSG','6814','EPSG','3313','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6815','Greek (Athens)',NULL,'EPSG','7004','EPSG','8912',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13838','geodetic_datum','EPSG','6815','EPSG','3254','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6816','Carthage (Paris)',NULL,'EPSG','7011','EPSG','8903','1925-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13839','geodetic_datum','EPSG','6816','EPSG','1618','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6817','NGO 1948 (Oslo)',NULL,'EPSG','7005','EPSG','8913','1948-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13840','geodetic_datum','EPSG','6817','EPSG','1352','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6818','System of the Unified Trigonometrical Cadastral Network (Ferro)',NULL,'EPSG','7004','EPSG','8909','1920-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13841','geodetic_datum','EPSG','6818','EPSG','1306','EPSG','1181');
INSERT INTO "geodetic_datum" VALUES('EPSG','6819','Nord Sahara 1959 (Paris)',NULL,'EPSG','7012','EPSG','8903','1959-01-01',NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13842','geodetic_datum','EPSG','6819','EPSG','1366','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6820','Gunung Segara (Jakarta)',NULL,'EPSG','7004','EPSG','8908',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13843','geodetic_datum','EPSG','6820','EPSG','1360','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6821','Voirol 1879 (Paris)',NULL,'EPSG','7011','EPSG','8903','1879-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13844','geodetic_datum','EPSG','6821','EPSG','1365','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6896','International Terrestrial Reference Frame 2005',NULL,'EPSG','7019','EPSG','8901','2000-01-01',2000.0,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13845','geodetic_datum','EPSG','6896','EPSG','1262','EPSG','1027');
INSERT INTO "geodetic_datum" VALUES('EPSG','6901','Ancienne Triangulation Francaise (Paris)',NULL,'EPSG','7027','EPSG','8914',NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13846','geodetic_datum','EPSG','6901','EPSG','1326','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6902','Nord de Guerre (Paris)',NULL,'EPSG','7027','EPSG','8903',NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "usage" VALUES('EPSG','13847','geodetic_datum','EPSG','6902','EPSG','1369','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6903','Madrid 1870 (Madrid)',NULL,'EPSG','7028','EPSG','8905','1870-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13848','geodetic_datum','EPSG','6903','EPSG','2366','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','6904','Lisbon 1890 (Lisbon)',NULL,'EPSG','7004','EPSG','8902','1937-01-01',NULL,NULL,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','13849','geodetic_datum','EPSG','6904','EPSG','1294','EPSG','1153');
INSERT INTO "geodetic_datum" VALUES('EPSG','1421','Greenland Reference 1996 ensemble',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,0.25,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','23453','geodetic_datum','EPSG','1421','EPSG','1107','EPSG','1056');
INSERT INTO "geodetic_datum" VALUES('EPSG','6258','European Terrestrial Reference System 1989 ensemble',NULL,'EPSG','7019','EPSG','8901',NULL,NULL,0.1,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','14235','geodetic_datum','EPSG','6258','EPSG','4755','EPSG','1026');
INSERT INTO "geodetic_datum" VALUES('EPSG','6326','World Geodetic System 1984 ensemble',NULL,'EPSG','7030','EPSG','8901',NULL,NULL,2.0,NULL,NULL,0);
INSERT INTO "usage" VALUES('EPSG','14343','geodetic_datum','EPSG','6326','EPSG','1262','EPSG','1245');
